//
// htmlArea v3.0 - Copyright (c) 2002 interactivetools.com, inc.
// This copyright notice MUST stay intact for use (see license.txt).
//
// A free WYSIWYG editor replacement for <textarea> fields.
// For full source code and docs, visit http://www.interactivetools.com/
//
// Version 3.0 developed by Mihai Bazon for InteractiveTools.
//	     http://students.infoiasi.ro/~mishoo
//
// $Id: htmlarea.js,v 1.29 2004/09/28 04:08:34 abrost Exp $
// Creates a new HTMLArea object.  Tries to replace the textarea with the given
// ID with it.
var clippboardval;
var mvContent;
var vFirst;
var vLast;
var vLength;
var vURL;
var elb, els;
function HTMLArea(textarea, config) {
	if (HTMLArea.checkSupportedBrowser()) {
		if (typeof config == "undefined") {
			this.config = new HTMLArea.Config();
		} else {
			this.config = config;
		}
		this._htmlArea = null;
		this._textArea = textarea;
		this._editMode = "wysiwyg";
		this.plugins = {};
		this._timerToolbar = null;
		this._mdoc = document; // cache the document, we need it in plugins
		this._timerUndo = null;
		this._undoQueue = new Array(this.config.undoSteps);
		this._undoPos = -1;
		this._customUndo = true;
	}
};


function fMessage(strVal){
	var retVal;
	retVal=Lang[strVal];
	if(!retVal || typeof retVal == "undefined" || retVal == ""){
		retVal="[" + strVal + "]";
	}
	return retVal;
};

HTMLArea.Config = function () {
	this.version = "3.0";

	this.width = "auto";
	this.height = "auto";

	// enable creation of a status bar?
	this.statusBar = true;
// maximum size of the undo queue
	this.undoSteps = 20;

	// the time interval at which undo samples are taken
	this.undoTimeout = 500;	// 1/2 sec.
	// the next parameter specifies whether the toolbar should be included
	// in the size or not.
	this.sizeIncludesToolbar = true;

	// style included in the iframe document
	this.pageStyle = "body { background-color: #fff; font-family: verdana,sans-serif; }";
	if (typeof _editor_url != "undefined") {
		this.editorURL = _editor_url;
	} else {
		this.editorURL = "";
	}

	// URL-s
	this.imgURL = "wysiwyg/images/";
	this.imgW="wysiwyg/img/";
	this.popupURL = "wysiwyg/popups/";

	// configuration for plugins
	this.plugins = {};

	/** CUSTOMIZING THE TOOLBAR
	 * -------------------------
	 *
	 * It is recommended that you customize the toolbar contents in an
	 * external file (i.e. the one calling HTMLArea) and leave this one
	 * unchanged.  That's because when we (InteractiveTools.com) release a
	 * new official version, it's less likely that you will have problems
	 * upgrading HTMLArea.
	 */
	this.toolbar = [
		[ "dsmode", "htmlmode", "prvmode", "separator", "fontname", "space",
		  "fontsize", "space",
		  "formatblock", "separator", "forecolor", "hilitecolor", "textindicator", "separator",
		  "bold", "italic", "underline", "strikethrough", "subscript", "superscript", "separator",
		  "justifyleft", "justifycenter", "justifyright", "justifyfull", "separator", "shbord", "shscr", "separator", "fullscreen"],
		
		["linebreak"],
		
		[ "cut", "copy", "paste","finde", "spell", "selectall", "separator", "undo", "redo", "separator",
		  "cleansel", "cleansel1", "cleansel2", "deltag", "separator", "insertimage", "createlink", "inserttable", "inserthorizontalrule", "insertsymbol",  
		  "separator", "insertform", "inserttextfield", "inserttextarea", "insertbutton", 
		  "insertsubmit", "insertcheck", "insertradio", "insertdropdown", "inserthidden",
		  "separator", "insertorderedlist", "insertunorderedlist", "outdent", "indent", "separator",
		  "tagedit", "tagprop", "tagstl", "separator" ]
		];

		this.fontname = {
		"Arial":	   'arial',
		"Courier New":	   'courier',
		"Georgia":	   'georgia',
		"Tahoma":	   'tahoma',
		"Times New Roman": 'times',
		"Verdana":	   'verdana',
		"impact":	   'impact',
		"WingDings":	   'wingdings'
	};

	this.fontsize = {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	};

	this.formatblock = {
		"Normal": "p",
		"Heading 1": "h1",
		"Heading 2": "h2",
		"Heading 3": "h3",
		"Heading 4": "h4",
		"Heading 5": "h5",
		"Heading 6": "h6",
		"Address": "address",
		"Formatted": "pre"
	};

	this.customSelects = {};
	
	function cut_copy_paste(e, cmd, obj) {
	try {
			e.execCommand(cmd);
	} catch (e) {
			if (HTMLArea.is_gecko) {
				alert("Some revisions of Mozilla/Gecko do not support programatic " +
				      "access to cut/copy/paste functions, for security reasons.  " +
				      "Your browser is one of them.  Please use the standard key combinations:\n" +
				      "CTRL-X for cut, CTRL-C for copy, CTRL-V for paste.");
				obj.element.style.display = "none";
			}
		}
	};

	// ADDING CUSTOM BUTTONS: please read below!
	// format of the btnList elements is "ID: [ ToolTip, Icon, Enabled in text mode?, ACTION ]"
	//    - ID: unique ID for the button.  If the button calls document.execCommand
	//	    it's wise to give it the same name as the called command.
	//    - ACTION: function that gets called when the button is clicked.
	//              it has the following prototype:
	//                 function(editor, buttonName)
	//              - editor is the HTMLArea object that triggered the call
	//              - buttonName is the ID of the clicked button
	//              These 2 parameters makes it possible for you to use the same
	//              handler for more HTMLArea objects or for more different buttons.
	//    - ToolTip: default tooltip, for cases when it is not defined in the -lang- file (HTMLArea.I18N)
	//    - Icon: path to an icon image file for the button (TODO: use one image for all buttons!)
	//    - Enabled in text mode: if false the button gets disabled for text-only mode; otherwise enabled all the time.
	this.btnList = {
		bold: [ fMessage("bold"), "wysiwyg/images/ed_format_bold.gif", false, false, true, function(e) {e.execCommand("bold");} ],
		italic: [ fMessage("italic"), "wysiwyg/images/ed_format_italic.gif", false, false, true, function(e) {e.execCommand("italic");} ],
		underline: [ fMessage("underline"), "wysiwyg/images/ed_format_underline.gif", false, false, true, function(e) {e.execCommand("underline");} ],
		strikethrough: [ fMessage("strikethrough"), "wysiwyg/images/ed_format_strike.gif", false, false, true, function(e) {e.execCommand("strikethrough");} ],
		subscript: [ fMessage("subscript"), "wysiwyg/images/ed_format_sub.gif", false, false, true, function(e) {e.execCommand("subscript");} ],
		superscript: [ fMessage("superscript"), "wysiwyg/images/ed_format_sup.gif", false, false, true, function(e) {e.execCommand("superscript");} ],
		justifyleft: [ fMessage("justifyleft"), "wysiwyg/images/ed_align_left.gif", false, false, true, function(e) {e.execCommand("justifyleft");} ],
		justifycenter: [ fMessage("justifycenter"), "wysiwyg/images/ed_align_center.gif", false, false, true, function(e) {e.execCommand("justifycenter");} ],
		justifyright: [ fMessage("justifyright"), "wysiwyg/images/ed_align_right.gif", false, false, true, function(e) {e.execCommand("justifyright");} ],
		justifyfull: [ fMessage("justifyfull"), "wysiwyg/images/ed_align_justify.gif", false, false, true, function(e) {e.execCommand("justifyfull");} ],
		insertorderedlist: [ fMessage("orderedlist"), "wysiwyg/images/ed_list_num.gif", false, false, true, function(e) {e.execCommand("insertorderedlist");} ],
		insertunorderedlist: [ fMessage("bulletedlist"), "wysiwyg/images/ed_list_bullet.gif", false, false, true, function(e) {e.execCommand("insertunorderedlist");} ],
		outdent: [ fMessage("decreaseindent"), "wysiwyg/images/ed_indent_less.gif", false, false, true, function(e) {e.execCommand("outdent");} ],
		indent: [ fMessage("increaseindent"), "wysiwyg/images/ed_indent_more.gif", false, false, true, function(e) {e.execCommand("indent");} ],
		forecolor: [ fMessage("fontcolor"), "wysiwyg/images/ed_color_fg.gif", false, false, true, function(e) {e.execCommand("forecolor");} ],
		hilitecolor: [ fMessage("backgroundcolor"), "wysiwyg/images/ed_color_bg.gif", false, false, true, function(e) {e.execCommand("hilitecolor");} ],
		inserthorizontalrule: [ fMessage("horizontalrule"), "wysiwyg/images/ed_hr.gif", false, false, true, function(e) {e.execCommand("inserthorizontalrule");} ],
		createlink: [ fMessage("insertweblink"), "wysiwyg/images/ed_link.gif", false, false, true, function(e) {e.execCommand("createlink", true);} ],
		insertimage: [ fMessage("insertimage"), "wysiwyg/img/pic.gif", false, false, true, function(e) {e.execCommand("insertimage");} ],
		inserttable: [ fMessage("inserttable"), "wysiwyg/images/insert_table.gif", false, false, true, function(e) {e.execCommand("inserttable");} ],
		undo: [ fMessage("undo"), "wysiwyg/images/ed_undo.gif", false, false, true, function(e) {e.execCommand("undo");} ],
		redo: [ fMessage("redo"), "wysiwyg/images/ed_redo.gif", false, false, true, function(e) {e.execCommand("redo");} ],
		cut: [ fMessage("cut"), "wysiwyg/images/ed_cut.gif", false, false, true, cut_copy_paste ],
		copy: [ fMessage("copy"), "wysiwyg/images/ed_copy.gif", false, false, true, cut_copy_paste ],
		paste: [ fMessage("paste"), "wysiwyg/images/ed_paste.gif", false, false, true, cut_copy_paste ],
		insertform: [ fMessage("insertform"), "wysiwyg/img/form-ins.gif", false, false, true, function(e) {e.execCommand("insertform");} ],
		inserttextfield: [ fMessage("inserttextfield"), "wysiwyg/img/form-textfield.gif", false, false, true, function(e) {e.execCommand("inserttextfield");} ],
		inserttextarea: [ fMessage("inserttextarea"), "wysiwyg/img/form-textarea.gif", false, false, true, function(e) {e.execCommand("inserttextarea");} ],
		insertbutton: [ fMessage("insertbutton"), "wysiwyg/img/form-button.gif", false, false, true, function(e) {e.execCommand("insertbutton");} ],
		insertsubmit: [ fMessage("insertbuttonsubmit"), "wysiwyg/img/form-submit.gif", false, false, true, function(e) {e.execCommand("insertsubmit");} ],
		insertcheck: [ fMessage("insertcheckbox"), "wysiwyg/img/form-check.gif", false, false, true, function(e) {e.execCommand("insertcheck");} ],
		insertradio: [ fMessage("insertradiobutton"), "wysiwyg/img/form-radio.gif", false, false, true, function(e) {e.execCommand("insertradio");} ],
		insertdropdown: [ fMessage("insertdropdownlist"), "wysiwyg/img/form-dropdown.gif", false, false, true, function(e) {e.execCommand("insertdropdown");} ],
		inserthidden: [ fMessage("inserthiddentextfield"), "wysiwyg/img/form-hidden.gif", false, false, true, function(e) {e.execCommand("inserthidden");} ],
		selectall: [ fMessage("selectall"), "wysiwyg/img/selectall.gif", false, false, true, function(e) {e.execCommand("selectall");} ],
		dsmode: [ fMessage("dsmode"), "wysiwyg/img/usermode.gif", true, true, true, function(e) {e.execCommand("dsmode");} ],
		htmlmode: [ fMessage("htmlmode"), "wysiwyg/img/html.gif", true, true, true, function(e) {e.execCommand("htmlmode");} ],
		prvmode: [ fMessage("previewmode"), "wysiwyg/img/preview.gif", true, true, true, function(e) {e.execCommand("prvmode");} ],
		insertsymbol: [ fMessage("insertsymbol"), "wysiwyg/img/symbols.gif", false, false, true, function(e) {e.execCommand("insertsymbol");} ],
		tagedit: [ fMessage("tagedition"), "wysiwyg/images/ed_html.gif", false, false, true, function(e) {e.execCommand("tagedit");} ],
		tagprop: [ fMessage("tagproperties"), "wysiwyg/img/tag-prop.gif", false, false, true, function(e) {e.execCommand("tagprop");} ],
		tagstl: [ fMessage("advancedtagproperties"), "wysiwyg/img/tag-stl.gif", false, false, true, function(e) {e.execCommand("tagstl");} ],
		finde: [ fMessage("findereplace"), "wysiwyg/img/find.gif", false, false, true, function(e) {e.execCommand("finde");} ],
		shbord: [ fMessage("showborders"), "wysiwyg/img/show-borders.gif", false, false, true, function(e) {e.execCommand("shbord");} ],
		shscr: [ fMessage("showtags"), "wysiwyg/img/show-scripts.gif", false, false, true, function(e) {e.execCommand("shscr");} ],
		cleansel: [ fMessage("clean1"), "wysiwyg/img/clean1.gif", false, false, true, function(e) {e.execCommand("cleansel");} ],
		cleansel1: [ fMessage("clean2"), "wysiwyg/img/clean2.gif", false, false, true, function(e) {e.execCommand("cleansel1");} ],
		cleansel2: [ fMessage("clean3"), "wysiwyg/img/clean3.gif", false, false, true, function(e) {e.execCommand("cleansel2");} ],
		deltag: [ fMessage("clean4"), "wysiwyg/img/clean4.gif", false, false, true, function(e) {e.execCommand("deltag");} ],
		spell: [ fMessage("checkspelling"), "wysiwyg/img/spellcheck.gif", false, false, true, function(e) {e.execCommand("spell");} ],
		fullscreen: [ fMessage("fullscreenmode"), "wysiwyg/img/fscreen.gif", true, true, true, function(e) {e.execCommand("fullscreen");} ]
	};
	/* ADDING CUSTOM BUTTONS
	 * ---------------------
	 *
	 * It is recommended that you add the custom buttons in an external
	 * file and leave this one unchanged.  That's because when we
	 * (InteractiveTools.com) release a new official version, it's less
	 * likely that you will have problems upgrading HTMLArea.
	 *
	 * Example on how to add a custom button when you construct the HTMLArea:
	 *
	 *   var editor = new HTMLArea("your_text_area_id");
	 *   var cfg = editor.config; // this is the default configuration
	 *   cfg.btnList["my-hilite"] =
	 *	[ function(editor) { editor.surroundHTML('<span style="background:yellow">', '</span>'); }, // action
	 *	  "Highlight selection", // tooltip
	 *	  "my_hilite.gif", // image
	 *	  false // disabled in text mode
	 *	];
	 *   cfg.toolbar.push(["linebreak", "my-hilite"]); // add the new button to the toolbar
	 *
	 * An alternate (also more convenient and recommended) way to
	 * accomplish this is to use the registerButton function below.
	 */
	// initialize tooltips from the I18N module
	//for (var i in this.btnList) {
	//	var btn = this.btnList[i];
	//	if (typeof HTMLArea.I18N.tooltips[i] != "undefined") {
	//		btn[0] = HTMLArea.I18N.tooltips[i];
	//	}
	//}
};

/** Helper function: register a new button with the configuration.  It can be
 * called with all 5 arguments, or with only one (first one).  When called with
 * only one argument it must be an object with the following properties: id,
 * tooltip, image, textMode, action.  Examples:
 *
 * 1. config.registerButton("my-hilite", "Hilite text", "my-hilite.gif", false, function(editor) {...});
 * 2. config.registerButton({
 *      id       : "my-hilite",      // the ID of your button
 *      tooltip  : "Hilite text",    // the tooltip
 *      image    : "my-hilite.gif",  // image to be displayed in the toolbar
 *      textMode : false,            // disabled in text mode
 *      action   : function(editor) { // called when the button is clicked
 *                   editor.surroundHTML('<span class="hilite">', '</span>');
 *                 },
 *      context  : "p"               // will be disabled if outside a <p> element
 *    });
 */
HTMLArea.Config.prototype.registerButton = function(id, tooltip, image, textMode, prvMode, dsMode, action, context) {
	var the_id;
	if (typeof id == "string") {
		the_id = id;
	} else if (typeof id == "object") {
		the_id = id.id;
	} else {
		alert(fMessage("error") + " [HTMLArea.Config::registerButton]:\n" + fMessage("invalidarguments"));
		return false;
	}
	// check for existing id
	if (typeof this.customSelects[the_id] != "undefined") {
		alert(fMessage("warning") + " [HTMLArea.Config::registerDropdown]:\n" + fMessage("adropdownwith"));
	}
	if (typeof this.btnList[the_id] != "undefined") {
		alert(fMessage("warning") + " [HTMLArea.Config::registerDropdown]:\n"+ fMessage("adropdownwithexists"));
	}
	switch (typeof id) {
	    case "string": this.btnList[id] = [ tooltip, image, textMode, prvMode, dsMode, action, context ]; break;
	    case "object": this.btnList[id.id] = [ id.tooltip, id.image, id.textMode, id.prvMode, id.dsMode, id.action, id.context ]; break;
	}
};

/** The following helper function registers a dropdown box with the editor
 * configuration.  You still have to add it to the toolbar, same as with the
 * buttons.  Call it like this:
 *
 * FIXME: add example
 */
HTMLArea.Config.prototype.registerDropdown = function(object) {
	// check for existing id
	if (typeof this.customSelects[object.id] != "undefined") {
		alert(fMessage("error") + " [HTMLArea.Config::registerDropdown]:\n" + fMessage("adropdownwith"));
	}
	if (typeof this.btnList[object.id] != "undefined") {
		alert(fMessage("error") + " [HTMLArea.Config::registerDropdown]:\n" + fMessage("adropdownwith"));
	}
	this.customSelects[object.id] = object;
};

/** Helper function: replace all TEXTAREA-s in the document with HTMLArea-s. */
HTMLArea.replaceAll = function(config) {
	var tas = document.getElementsByTagName("textarea");
	for (var i = tas.length; i > 0; (new HTMLArea(tas[--i], config)).generate());
};

/** Helper function: replaces the TEXTAREA with the given ID with HTMLArea. */
HTMLArea.replace = function(id, config) {
	var ta = document.getElementById(id);
	return ta ? (new HTMLArea(ta, config)).generate() : null;
};
var countNL=0;
var countDiv=0;
// Creates the toolbar and appends it to the _htmlarea
HTMLArea.prototype._createToolbar = function () {
	var editor = this;	// to access this in nested functions

	var toolbar = document.createElement("div");
	this._toolbar = toolbar;
	toolbar.className = "toolbar";
	toolbar.unselectable = "1";
	var tb_row = null;
	var tb_objects = new Object();
	this._toolbarObjects = tb_objects;

	// creates a new line in the toolbar
	function newLine() {
		var table = document.createElement("table");
		table.id="toolbar"+countNL;
		table.border = "0px";
		table.cellSpacing = "0px";
		table.cellPadding = "0px";
		toolbar.appendChild(table);
		// TBODY is required for IE, otherwise you don't see anything
		// in the TABLE.
		var tb_body = document.createElement("tbody");
		table.appendChild(tb_body);
		tb_row = document.createElement("tr");
		tb_body.appendChild(tb_row);
		var td_first=document.createElement("td");
		tb_row.appendChild(td_first);
		td_first.innerHTML="<img src='img/ft-1.gif' height=24 width=9>";
		countNL++;
	}; // END of function: newLine
	// init first line
	newLine();

	// updates the state of a toolbar element.  This function is member of
	// a toolbar element object (unnamed objects created by createButton or
	// createSelect functions below).
	function setButtonStatus(id, newval) {
		var oldval = this[id];
		var el = this.element;
		if (oldval != newval) {
			switch (id) {
			    case "enabled":
				if (newval) {
					HTMLArea._removeClass(el, "buttonDisabled");
					el.disabled = false;
				} else {
					HTMLArea._addClass(el, "buttonDisabled");
					el.disabled = true;
				}
				break;
			    case "active":
				if (newval) {
					HTMLArea._addClass(el, "buttonPressed");
				} else {
					HTMLArea._removeClass(el, "buttonPressed");
				}
				break;
			}
			this[id] = newval;
		}
	}; // END of function: setButtonStatus	

	// this function will handle creation of combo boxes.  Receives as
	// parameter the name of a button as defined in the toolBar config.
	// This function is called from createButton, above, if the given "txt"
	// doesn't match a button.
	function createSelect(txt) {
		var options = null;
		var el = null;
		var cmd = null;
		var customSelects = editor.config.customSelects;
		var context = null;
		switch (txt) {
		    case "fontsize":
		    case "fontname":
		    case "formatblock":
			// the following line retrieves the correct
			// configuration option because the variable name
			// inside the Config object is named the same as the
			// button/select in the toolbar.  For instance, if txt
			// == "formatblock" we retrieve config.formatblock (or
			// a different way to write it in JS is
			// config["formatblock"].
			options = editor.config[txt];
			cmd = txt;
			break;
		    default:
			// try to fetch it from the list of registered selects
			cmd = txt;
			var dropdown = customSelects[cmd];
			if (typeof dropdown != "undefined") {
				options = dropdown.options;
				context = dropdown.context;
			} else {
				alert(fMessage("error") + " [createSelect]:\n" + fMessage("cantfinddefinition"));
			}
			break;
		}
		if (options) {
			el = document.createElement("select");
			var obj = {
				name	: txt, // field name
				element : el,	// the UI element (SELECT)
				enabled : true, // is it enabled?
				text	: false, // enabled in text mode?
				prv	: false,
				ds	: true,
				cmd	: cmd, // command ID
				state	: setButtonStatus, // for changing state
				context : context
			};
			tb_objects[txt] = obj;
			for (var i in options) {
				var op = document.createElement("option");
				op.appendChild(document.createTextNode(i));
				op.value = options[i];
				el.appendChild(op);
			}
			HTMLArea._addEvent(el, "change", function () {
				editor._comboSelected(el, txt);
			});
		}
		return el;
	}; // END of function: createSelect

	// appends a new button to toolbar
	function createButton(txt) {
		// the element that will be created
		var el = null;
		var btn = null;
		switch (txt) {
		    case "separator":
			el = document.createElement("div");
			el.id="divtoolbar"+countDiv;
			countDiv++;
			el.className = "separator";
			break;
		    case "space":
			el = document.createElement("div");
			el.className = "space";
			break;
		    case "linebreak":
			newLine();
			return false;
		    case "textindicator":
			el = document.createElement("div");
			el.appendChild(document.createTextNode("A"));
			el.className = "indicator";
			el.title = fMessage("currentstyle");
			var obj = {
				name	: txt, // the button name (i.e. 'bold')
				element : el, // the UI element (DIV)
				enabled : true, // is it enabled?
				active	: false, // is it pressed?
				text	: false, // enabled in text mode?
				prv	: false,
				ds	: true,
				cmd	: "textindicator", // the command ID
				state	: setButtonStatus // for changing state
			};
			tb_objects[txt] = obj;
			break;
		    default:
			btn = editor.config.btnList[txt];
		}
		if (!el && btn) {
			el = document.createElement("div");
			el.title = btn[0];
			el.className = "button";
			// let's just pretend we have a button object, and
			// assign all the needed information to it.
			//alert(btn[1]+btn[2]+btn[3]+btn[4]+btn[5]+btn[0]);
			var obj
				
			obj = {
				name	: txt, // the button name (i.e. 'bold')
				element : el, // the UI element (DIV)
				enabled : true, // is it enabled?
				active	: false, // is it pressed?
				text	: btn[2], // enabled in text mode?
				prv	: btn[3],
				ds	: btn[4],
				cmd	: btn[5], // the command ID
				state	: setButtonStatus, // for changing state
				context : btn[6] || null // enabled in a certain context?
			};
			if(txt=="shbord"){
			elb=el;
				if(editor.showborders==true){
				HTMLArea._addClass(el, "buttonPressed");
				}else{
				HTMLArea._removeClass(el, "buttonPressed");
				}
				}
				if(txt=="shscr"){
				els=el;
				if(editor.showscripts==true){
				HTMLArea._addClass(el, "buttonPressed");
				}else{
				HTMLArea._removeClass(el, "buttonPressed");
				}
				}
			tb_objects[txt] = obj;
			// handlers to emulate nice flat toolbar buttons
			HTMLArea._addEvent(el, "mouseover", function () {
				if (obj.enabled) {
					HTMLArea._addClass(el, "buttonHover");
				}
			});
			HTMLArea._addEvent(el, "mouseout", function () {
				if (obj.enabled) with (HTMLArea) {
					_removeClass(el, "buttonHover");
					_removeClass(el, "buttonActive");
					(obj.active) && _addClass(el, "buttonPressed");
				}
			});
			HTMLArea._addEvent(el, "mousedown", function (ev) {
				if (obj.enabled) with (HTMLArea) {
					_addClass(el, "buttonActive");
					_removeClass(el, "buttonPressed");
					_stopEvent(is_ie ? window.event : ev);
				}
			});
			// when clicked, do the following:
			HTMLArea._addEvent(el, "click", function (ev) {
				if (obj.enabled) with (HTMLArea) {
					_removeClass(el, "buttonActive");
					_removeClass(el, "buttonHover");
					obj.cmd(editor, obj.name, obj);
					_stopEvent(is_ie ? window.event : ev);
				}
			});
			var img = document.createElement("img");
			img.src = editor.imgURL(btn[1]);
			img.style.width = "18px";
			img.style.height = "18px";
			el.appendChild(img);
		} else if (!el) {
			el = createSelect(txt);
		}
		if (el) {
			var tb_cell = document.createElement("td");
			tb_row.appendChild(tb_cell);
			tb_cell.appendChild(el);
		} else {
			alert(fMessage("fixme") + " " + fMessage("unknowntoolbaritem") + txt);
		}
		return el;
	};


	var first = true;
	for (var i in this.config.toolbar) {
		//if (!first) {
		//	createButton("linebreak");
		//} else {
		//	first = false;
		//}
		var group = this.config.toolbar[i];
		for (var j in group) {
			var code = group[j];
			if (/^([IT])\[(.*?)\]/.test(code)) {
				// special case, create text label
				var l7ed = RegExp.$1 == "I"; // localized?
				var label = RegExp.$2;
				if (l7ed) {
					label = HTMLArea.I18N.custom[label];
				}
				var tb_cell = document.createElement("td");
				tb_row.appendChild(tb_cell);
				tb_cell.className = "label";
				tb_cell.innerHTML = label;
			} else {
				createButton(code);
			}
		}
	}

	this._htmlArea.appendChild(toolbar);
};

HTMLArea.prototype._createStatusBar = function() {
	var div = document.createElement("div");
	div.className = "statusBar";
	this._htmlArea.appendChild(div);
	this._statusBar = div;
	var le = document.createElement("span");
	le.className = "statusBar";
	le.innerHTML="<img src='img/ft-1.gif' height=24 width=9>"
	
	this._statusBar.appendChild(le);
	// creates a holder for the path view
	div = document.createElement("span");
	div.className = "statusBarTree";
	this._statusBarTree = div;
	this._statusBar.appendChild(div);
	if (!this.config.statusBar) {
		// disable it...
		div.style.display = "none";
	}
};
var hg1;
// Creates the HTMLArea object and replaces the textarea with it.
HTMLArea.prototype.generate = function () {
	var editor = this;	// we'll need "this" in some nested functions
	editor.url="";
	this._all=document.createElement("div");
	this._all.style.width = "100%";
 	this._all.style.height = "100%";
	var textarea = this._textArea;
	if (typeof textarea == "string") {
		// it's not element but ID
		this._textArea = textarea = document.getElementById(textarea);
	}
	this._ta_size = {
		w: textarea.offsetWidth,
		h: textarea.offsetHeight
	};
	textarea.style.display = "none";

	// create the editor framework
	var htmlarea = document.createElement("div");
	htmlarea.className = "htmlarea";
	this._htmlArea = htmlarea;

	// insert the editor before the textarea.
textarea.parentNode.appendChild(this._all);
this._all.appendChild(htmlarea);
this._all.appendChild(textarea);

	if (textarea.form) {
		// we have a form, on submit get the HTMLArea content and
		// update original textarea.
		textarea.form.onsubmit = function() {
			editor._textArea.value = editor.getHTML();
		};
	}

	// add a handler for the "back/forward" case -- on body.unload we save
	// the HTML content into the original textarea.
	window.onunload = function() {
		editor._textArea.value = editor.getHTML();
	};

	// creates & appends the toolbar
	this._createToolbar();

	// create the IFRAME
	var iframe = document.createElement("iframe");
	htmlarea.appendChild(iframe);

	this._iframe = iframe;
	// creates & appends the status bar, if the case
	this._createStatusBar();

	// remove the default border as it keeps us from computing correctly
	// the sizes.  (somebody tell me why doesn't this work in IE)

	if (!HTMLArea.is_ie) {
		iframe.style.borderWidth = "0px";
	// iframe.frameBorder = "1";
	// iframe.marginHeight = "0";
	// iframe.marginWidth = "0";
	}

	// size the IFRAME according to user's prefs or initial textarea
	var height = (this.config.height == "auto" ? (this._ta_size.h + "px") : this.config.height);
	height = parseInt(height);
	var width = (this.config.width == "auto" ? (this._ta_size.w + "px") : this.config.width);
	width = parseInt(width);
	if (!HTMLArea.is_ie) {
		height -= 2;
		width -= 2;
	}
hg=this._toolbar.offsetHeight;
hg1=this._statusBar.offsetHeight;
	iframe.style.width ="100%";// width + "px";
	if (this.config.sizeIncludesToolbar) {
		// substract toolbar height
		var er=this._toolbar.offsetHeight/3;
		var er1;
		er1=height;
		height -= this._toolbar.offsetHeight;
		height -= this._statusBar.offsetHeight;
		er1 -= er;
	}
	if (height < 0) {
		height = 0;
	}
	iframe.style.height = height-35 + "px";

	// the editor including the toolbar now have the same size as the
	// original textarea.. which means that we need to reduce that a bit.
	//textarea.style.width = iframe.style.width;
 	textarea.style.height = er1-5-35 +"px";//iframe.style.height;

	// IMPORTANT: we have to allow Mozilla a short time to recognize the
	// new frame.  Otherwise we get a stupid exception.

	initIframe();
	//setTimeout(initIframe,10);
	
	setTimeout(init, HTMLArea.is_gecko ? 10 : 0);
};
function init(){
	//editor.setMode('wysiwyg');
	editor.updateToolbar();
	editor.focusEditor();
}

	function initIframe() {
		doc = editor._iframe.contentWindow.document;
		if (!doc) {
			// Try again..
			// FIXME: don't know what else to do here.  Normally
			// we'll never reach this point.
			if (HTMLArea.is_gecko) {
				setTimeout(initIframe, 10);
				return false;
			} else {
				alert(fMessage("error")+ " " + fMessage("iframeinitialised"));
			}
		}
		if (HTMLArea.is_gecko) {
			// enable editable mode for Mozilla
			try{
			doc.designMode = "on";
			}catch(e){
			}
		}
		var vBod;
		if(typeof mvContent != "undefined"){
			vBod = getBody(mvContent);
		}else{
			vBod = editor._textArea.value;
		}
		var tmpFirst=editor.first;
		try{
		var bod=tmpFirst.match(/<body(.*?)>/gim);
		}catch(e){
		var bod=false;
		}
		if(typeof tmpFirst != "undefined"){
			tmpFirst=editor.first.replace(/<base(.*?)>/gim,"");
			tmpFirst=tmpFirst.replace(/<body(.*?)>/gim,"");
			tmpFirst=tmpFirst.replace("/<html>/gim","");
			tmpFirst=tmpFirst.replace("/<head>/gim","");
			tmpFirst=tmpFirst.replace("/<\/head>/","");
		}else{
			tmpFirst="";
		}
		editor._doc = doc;
		doc.open();
		var html="";
		html += "<html>\n";
		html += "<head>\n";
		html += editor.base;
		html += "\n";
		html += tmpFirst;
		html += "<style>\n";
		if(editor.showborders==true){
			html += "TD {border:#cccccc 1px dashed;}\n";
		}
		html += "form {border:#00ff00 1px dashed;}\n";
		html += "</style>\n";
		html += "</head>\n";
		if(bod){
			html += bod[0]+"\n";
		}else{
			html += "<body>\n";
		}
		//alert(editor.bod);
		if(editor.bod=="undefined" || typeof editor.bod=="undefined"){
		//alert(editor.bod);
		}else{ 
		html += editor.bod;//vBod;
		}
		html += "</body>\n";
		html += "</html>";
		//alert(html);
		doc.write(html);
		doc.close();
		//alert(doc.body);

		// intercept some events; for updating the toolbar & keyboard handlers
		HTMLArea._addEvents
			(doc, ["focus","keydown", "keypress", "mousedown", "mouseup", "drag"],//["dblclick",  "keydown", "keypress", "mousedown", "mouseup", "drag", "select"],
			 function (event) {
				 return editor._editorEvent(HTMLArea.is_ie ? editor._iframe.contentWindow.event : event);
			 });
		//editor.updateToolbar();
		//editor.focusEditor();
	};
	
var hg;
var doc;
var docp;
var iframep;
var mvMode;
// Switches editor mode; parameter can be "textmode" or "wysiwyg".  If no
// parameter was passed this function toggles between modes.
HTMLArea.prototype.setMode = function(mode) {

mvMode=mode;
editor.hideBut();


if(this._editMode=="wysiwyg"){
mvContent=setBody(HTMLArea.getHTML(this._doc.body, false));
}
	switch (mode) {
	    case "html":
	    if(iframep!=null){
	    this._htmlArea.removeChild(iframep);
	    iframep=null;
	    }
	    iframep=null;
		this._textArea.value = this.getHTML();
		this._iframe.style.display = "none";
		this._textArea.style.display = "block";
		if (this.config.statusBar) {
			this._statusBar.style.display = "none";
		}
		
		break;
	    case "wysiwyg":
	    if(iframep!=null){
	    this._htmlArea.removeChild(iframep);
	    iframep=null;
	    }
	    
		if (HTMLArea.is_gecko) {
			// disable design mode before changing innerHTML
			try{
				this._doc.designMode = "off";
			}catch(e){
			}
		}
		//mvContent=setBody(HTMLArea.getHTML(this._doc.body, false));
		//initIframe();
		this._doc.body.innerHTML = this.getHTML();
		this._iframe.style.display = "block";
		this._textArea.style.display = "none";
		if (HTMLArea.is_gecko) {
			// we need to refresh that info for Moz-1.3a
		try{
			this._doc.designMode = "on";
		}catch(e){
			}
			
		}
		if (this.config.statusBar) {
			this._statusBar.style.display = "";
		}
		break;
		case "preview":
		if(iframep!=null){
	    this._htmlArea.removeChild(iframep);
	    iframep=null;
	    }
		this._iframe.style.display = "none";
		this._textArea.style.display = "none";
		if (this.config.statusBar) {
			this._statusBar.style.display = "none";
		}
		iframep = document.createElement("iframe");
		this._htmlArea.appendChild(iframep);
		
		this._iframep = iframep;
		iframep.style.borderWidth = "0px";
		var height = (this.config.height == "auto" ? (this._ta_size.h + "px") : this.config.height);
	height = parseInt(height);
	var width = (this.config.width == "auto" ? (this._ta_size.w + "px") : this.config.width);
	width = parseInt(width);
	iframep.style.width = "100%";// width -22+ "px";
		height -= this._toolbar.offsetHeight/3;
		//height -= this._statusBar.offsetHeight;
	if (height < 0) {
		height = 0;
	}
	//if(editor.fullscreen=="true"){
		iframep.style.height=this._textArea.style.height;
	//}else{
	//	iframep.style.height =  height-20 -35+ "px";
	//}
	//alert(this._textArea.style.height);
	//alert(iframep.style.height);
	//this._textArea.style.width = iframep.style.width;
 	//this._textArea.style.height = iframep.style.height;
function initIframep() {
		docp = editor._iframep.contentWindow.document;
		if (!docp) {
			// Try again..
			// FIXME: don't know what else to do here.  Normally
			// we'll never reach this point.
			if (HTMLArea.is_gecko) {
				setTimeout(initIframep, 10);
				return false;
			} else {
				alert(fMessage("error")+ " " + fMessage("iframeinitialised"));
			}
		}
		if (HTMLArea.is_gecko) {

		}
		editor._docp = docp;
		docp.open();
		var html = "<html>\n";
		docp.write(editor.base+mvContent);
		docp.close();



		editor.focusEditor();
		// intercept some events; for updating the toolbar & keyboard handlers
		//HTMLArea._addEvents
		//	(doc, ["keydown", "keypress", "mousedown", "mouseup", "drag"],
		//	 function (event) {
		//		 return editor._editorEvent(HTMLArea.is_ie ? editor._iframe.contentWindow.event : event);
		//	 });
		//editor.updateToolbar();
	};
	initIframep();
	
		docp.designMode = "off";
		docp.innerHTML = this.getHTML();
		
		
		break;
	    default:
		alert(fMessage("mode") + mode + fMessage("notdefined"));
		return false;
	}
	this._editMode = mode;
	this.focusEditor();
};

/***************************************************
 *  Category: PLUGINS
 ***************************************************/

// Create the specified plugin and register it with this HTMLArea
HTMLArea.prototype.registerPlugin = function(pluginName) {
	this.plugins[pluginName] = eval("new " + pluginName + "(this);");
};

// static function that loads the required plugin and lang file, based on the
// language loaded already for HTMLArea.  You better make sure that the plugin
// _has_ that language, otherwise shit might happen ;-)
HTMLArea.loadPlugin = function(pluginName) {
	var editorurl = '';
	if (typeof _editor_url != "undefined") {
		editorurl = _editor_url + "/";
	}
	var dir = editorurl + "plugins/" + pluginName;
	var plugin = pluginName.replace(/([a-z])([A-Z])([a-z])/g,
					function (str, l1, l2, l3) {
						return l1 + "-" + l2.toLowerCase() + l3;
					}).toLowerCase() + ".js";
	document.write("<script type='text/javascript' src='" + dir + "/" + plugin + "'></script>");
	document.write("<script type='text/javascript' src='" + editorurl + "lang/" + editor.lang + ".js'></script>");
};

/***************************************************
 *  Category: EDITOR UTILITIES
 ***************************************************/

HTMLArea.prototype.forceRedraw = function() {
	this._doc.body.style.visibility = "hidden";
	this._doc.body.style.visibility = "visible";
};

// focuses the iframe window.  returns a reference to the editor document.
HTMLArea.prototype.focusEditor = function() {
	switch (this._editMode) {
	    case "wysiwyg" : 
	    try{
	    this._iframe.contentWindow.focus(); break;
	    }catch(e){
	    
	    }
	    case "html": this._textArea.focus(); break;
	    case "preview": this._iframe.contentWindow.focus(); break;
	    default	   : alert(fMessage("mode") + this._editMode  + fMessage("notdefined"));
	}
	return this._doc;
};


// takes a snapshot of the current text (for undo)
HTMLArea.prototype._undoTakeSnapshot = function() {
if(editor._editMode=="wysiwyg"){
	++this._undoPos;
	if (this._undoPos >= this.config.undoSteps) {
		// remove the first element
		this._undoQueue.shift();
		--this._undoPos;
	}
	// use the fasted method (getInnerHTML);
	var take = true;
	var txt = this.getInnerHTML();
	if (this._undoPos > 0)
		take = (this._undoQueue[this._undoPos - 1] != txt);
	if (take) {
		this._undoQueue[this._undoPos] = txt;
		//alert(this._undoPos);
	} else {
		this._undoPos--;
	}
}	
};

HTMLArea.prototype.undo = function() {
	if (this._undoPos > 0) {
		var txt = this._undoQueue[--this._undoPos];
		if (txt) this.setHTML(txt);
		else ++this._undoPos;
	}
	
};

HTMLArea.prototype.redo = function() {
	if (this._undoPos < this._undoQueue.length - 1) {
		var txt = this._undoQueue[++this._undoPos];
		if (txt) this.setHTML(txt);
		else --this._undoPos;
	}
};

HTMLArea.prototype.hideBut = function() {
var des;
if(mvMode=="wysiwyg"){
des=true;
}else{
des==false;
}
for (var i in this._toolbarObjects) {
		var btn = this._toolbarObjects[i];
		if(!des && btn.name != "dsmode" && btn.name != "htmlmode" && btn.name != "prvmode" ){
			btn.element.style.display = "none";
			var eltl=document.getElementById("toolbar1");
			eltl.style.display = "none";
			eltl=document.getElementById("toolbar2");
			eltl.style.display = "none";
			for(var f=1;f<countDiv;f++){
				eltl=document.getElementById("divtoolbar"+f);
				eltl.className = "separator1";
			}
		}else{
			btn.element.style.display = "";
			var eltl=document.getElementById("toolbar1");
			eltl.style.display = "";
			eltl=document.getElementById("toolbar2");
			eltl.style.display = "";
			for(var f=1;f<countDiv;f++){
				eltl=document.getElementById("divtoolbar"+f);
				eltl.className = "separator";
			}
		}
	}
};

// updates enabled/disable/active state of the toolbar elements
HTMLArea.prototype.updateToolbar = function(noStatus) {
	var doc = this._doc;
	var text = (this._editMode == "html");
	var des = (this._editMode == "wysiwyg");
	var prv = (this._editMode == "preview");
	var ancestors = null;
	if (des) {
		ancestors = this.getAllAncestors();
		if (this.config.statusBar && !noStatus) {
		
			this._statusBarTree.innerHTML = ''; // clear
			for (var i = ancestors.length; --i >= 0;) {
				var el = ancestors[i];
				if (!el) {
					// hell knows why we get here; this
					// could be a classic example of why
					// it's good to check for conditions
					// that are impossible to happen ;-)
					continue;
				}
				var a = document.createElement("a");
				a.href = "#";
				a.el = el;
				a.editor = this;
				a.onclick = function() {
					
					this.blur();
					this.editor.selectNodeContents(this.el);
					this.editor.updateToolbar(false);
					
					return false;
				};
				//a.oncontextmenu = function() {
					// TODO: add context menu here
				//	this.blur();
				//	var info = "Inline style:\n\n";
				//	info += this.el.style.cssText.split(/;\s*/).join(";\n");
				//	alert(info);
				//	return false;
				//};
				var txt;
				if(el.id.toLowerCase()=="asp" || el.id.toLowerCase()=="php" || el.id.toLowerCase()=="script"){
				txt=el.id;
				}else{
				txt = el.tagName.toUpperCase();
				a.title = el.style.cssText;
				//if (el.id) {
				//	txt += "#" + el.id;
				//}
				//if (el.className) {
				//	txt += "." + el.className;
				//}
				}
				
				if(i==0){
				var strg=document.createElement("strong");
				a.appendChild(strg);
				strg.appendChild(document.createTextNode(txt));
				//a.appendChild(document.createTextNode(txt));
				}else{
				a.appendChild(document.createTextNode(txt));
				}
				this._statusBarTree.appendChild(a);
				if (i != 0) {
					this._statusBarTree.appendChild(document.createTextNode(" "));//String.fromCharCode(0xbb)));
				}
				
			}
		}
		//alert(ancestors[0]);
	try{	
	var kids=ancestors[0].childNodes;
	}catch(e){
	var kids=null;
	}
	if(kids!=null){
	var fn=document.createElement("font");
	fn.style.color="gray";
	this._statusBarTree.appendChild(fn);
	fn.appendChild(document.createTextNode(" ("));
		for (var i5 = 0; i5 < kids.length; i5++) {
		
			var el = kids[i5];
				if (!el) {
					// hell knows why we get here; this
					// could be a classic example of why
					// it's good to check for conditions
					// that are impossible to happen ;-)
					continue;
				}
				if(el.nodeType==1){
				var a = document.createElement("a");
				a.style.color="gray";
				a.href = "#";
				a.el = el;
				a.editor = this;
				a.onclick = function() {
						this.blur();
						this.editor.selectNodeContents(this.el);
						this.editor.updateToolbar(false);
					return false;
				};
				//a.oncontextmenu = function() {
					// TODO: add context menu here
				//	this.blur();
				//	var info = "Inline style:\n\n";
				//	info += this.el.style.cssText.split(/;\s*/).join(";\n");
				//	alert(info);
				//	return false;
				//};
				var txt;
				if(el.id.toLowerCase()=="asp" || el.id.toLowerCase()=="php" || el.id.toLowerCase()=="script"){
					txt=el.id;
				}else{
					txt = el.tagName.toUpperCase();
					a.title = el.style.cssText;
				}
				
				a.appendChild(document.createTextNode(txt));
				this._statusBarTree.appendChild(a);
				//if (i != 0) {
					this._statusBarTree.appendChild(document.createTextNode(" "));//String.fromCharCode(0xbb)));
				//}
				}
		
		}
		fn=document.createElement("font");
		fn.style.color="gray";
		this._statusBarTree.appendChild(fn);
		fn.appendChild(document.createTextNode(")"));	
	
	}

}
	
	
	for (var i in this._toolbarObjects) {
		var btn = this._toolbarObjects[i];
		var cmd = i;
		var inContext = true;
		if (btn.context && des) {
			inContext = false;
			var context = btn.context;
			var attrs = [];
			if (/(.*)\[(.*?)\]/.test(context)) {
				context = RegExp.$1;
				attrs = RegExp.$2.split(",");
			}
			context = context.toLowerCase();
			var match = (context == "*");
			for (var k in ancestors) {
				if (!ancestors[k]) {
					// the impossible really happens.
					continue;
				}
				if (match || (ancestors[k].tagName.toLowerCase() == context)) {
					inContext = true;
					for (var ka in attrs) {
						if (!eval("ancestors[k]." + attrs[ka])) {
							inContext = false;
							break;
						}
					}
					if (inContext) {
						break;
					}
				}
			}
		}
		
		btn.state("enabled", (des || btn.text) && inContext);
		if (typeof cmd == "function") {
			continue;
		}
		// look-it-up in the custom dropdown boxes
		var dropdown = this.config.customSelects[cmd];
		if ((des || btn.text) && (typeof dropdown != "undefined")) {
			dropdown.refresh(this);
			continue;
		}
		
		switch (cmd) {
		    case "fontname":
		    case "fontsize":
		    case "formatblock":
		    
		    if (des) {
				
				var value="";
				try{
				value = ("" + doc.queryCommandValue(cmd)).toLowerCase();
				}catch(e){
				break;
				}
				
				if (value=="") {
					btn.element.selectedIndex = 0;
					break;
				}
	
				var options = this.config[cmd];//this._doc.getElementByName("fontname");
				var k = 0;
				
				for (var j in options) {
					var temp=options[j];
					if (value.toLowerCase().match(temp)) {
						btn.element.selectedIndex = k;
						break;
					}
					++k;
				}
			}
		    break;
		    
		    case "textindicator":
			if (des) {
				try {with (btn.element.style) {
					backgroundColor = HTMLArea._makeColor(
						doc.queryCommandValue(HTMLArea.is_ie ? "backcolor" : "hilitecolor"));
					if (/transparent/i.test(backgroundColor)) {
						// Mozilla
						backgroundColor = HTMLArea._makeColor(doc.queryCommandValue("backcolor"));
					}
					color = HTMLArea._makeColor(doc.queryCommandValue("forecolor"));
					fontFamily = doc.queryCommandValue("fontname");
					fontWeight = doc.queryCommandState("bold") ? "bold" : "normal";
					fontStyle = doc.queryCommandState("italic") ? "italic" : "normal";
				}} catch (e) {
				}
			}
			break;
		    case "htmlmode": btn.state("active", text); break;
		    case "prvmode": btn.state("active", prv); break;
		    case "dsmode": btn.state("active", des); break;
		    default:
			try {
				btn.state("active", (des && doc.queryCommandState(cmd)));
			} catch (e) {}
		}
	}
	// take undo snapshots
	if (this._customUndo && !this._timerUndo) {
		this._undoTakeSnapshot();
		var editor = this;
		this._timerUndo = setTimeout(function() {
			editor._timerUndo = null;
		}, this.config.undoTimeout);
	}
	
	var masEl;
	masEl=this._doc.getElementsByTagName("input");
	for(var j=0;j<masEl.length;j++){
		var el=masEl[j];
		if(el.type.toLowerCase()=="radio" || el.type.toLowerCase()=="checkbox"){
			
		}else{
			HTMLArea._addEvent(el, "mouseup", function () {
				var pn=this;
				try{
				editor.selectNodeContents(pn);
				}catch(e){
				}
			});
		}
	}
	masEl=this._doc.getElementsByTagName("textarea");
	for(var j=0;j<masEl.length;j++){
		var el=masEl[j];
		HTMLArea._addEvent(el, "mouseup", function () {
				var pn=this;
				try{
				editor.selectNodeContents(pn);
				}catch(e){
				}
			});
	}
	masEl=this._doc.getElementsByTagName("img");
	for(var j=0;j<masEl.length;j++){
		var el=masEl[j];
		HTMLArea._addEvent(el, "mouseup", function () {
				var pn=this;
				try{
				editor.selectNodeContents(pn);
				}catch(e){
				}
			});
	}
	//masEl=this._doc.getElementsByTagName("option");
	//for(var j=0;j<masEl.length;j++){
	//	var el=masEl[j];
	//	HTMLArea._addEvent(el, "mouseup", function () {
	//			var pn=this;
	//			try{
	//			editor.selectNodeContents(pn);
	//			}catch(e){
	//			}
	//		});
	//}
	//	masEl=this._doc.getElementsByTagName("option");
	//for(var j=0;j<masEl.length;j++){
	//	var el=masEl[j];
	//	HTMLArea._addEvent(el, "click", function () {
	//			var pn=this;
	//			try{
	//			
	//			editor.selectNodeContents(pn.parentNode);
	//			}catch(e){
	//			}
	//		});
	//}
	
};


function fAddEventOnElement(el){
	editor.selectNodeContent(el);

	//alert(HTMLArea.getHTML(el,true));
	//this.insertHTML(HTMLArea.getHTML(el,true));
	
};

/** Returns a node after which we can insert other nodes, in the current
 * selection.  The selection is removed.  It splits a text node, if needed.
 */
HTMLArea.prototype.insertNodeAtSelection = function(toBeInserted) {
	if (!HTMLArea.is_ie) {
		var sel = this._getSelection();
		var range = this._createRange(sel);
		// remove the current selection
		sel.removeAllRanges();
		range.deleteContents();
		var node = range.startContainer;
		var pos = range.startOffset;
		switch (node.nodeType) {
		    case 3: // Node.TEXT_NODE
			// we have to split it at the caret position.
			if (toBeInserted.nodeType == 3) {
			
				// do optimized insertion
				node.insertData(pos, toBeInserted.data);
				range = this._createRange();
				range.setEnd(node, pos + toBeInserted.length);
				range.setStart(node, pos + toBeInserted.length);
				sel.addRange(range);
			} else {
				node = node.splitText(pos);
				var selnode = toBeInserted;
				if (toBeInserted.nodeType == 11 /* Node.DOCUMENT_FRAGMENT_NODE */) {
					selnode = selnode.firstChild;
				}
				node.parentNode.insertBefore(toBeInserted, node);
				this.selectNodeContents(selnode);
				this.updateToolbar();
			}
			break;
		    case 1: // Node.ELEMENT_NODE
			var selnode = toBeInserted;
			if (toBeInserted.nodeType == 11 /* Node.DOCUMENT_FRAGMENT_NODE */) {
				selnode = selnode.firstChild;
			}
			node.insertBefore(toBeInserted, node.childNodes[pos]);
			this.selectNodeContents(selnode);
			this.updateToolbar();
			break;
		}
	} else {
		return null;	// this function not yet used for IE <FIXME>
	}
};

// Returns the deepest node that contains both endpoints of the selection.
HTMLArea.prototype.getParentElement = function() {
	var sel = this._getSelection();
	var range = this._createRange(sel);
	if (HTMLArea.is_ie) {
		return range.parentElement ? range.parentElement() : this._doc.body;
	} else {
		var p = range.commonAncestorContainer;
		while (p.nodeType == 3) {
			p = p.parentNode;
		}
		return p;
	}
};



// Returns an array with all the ancestor nodes of the selection.
HTMLArea.prototype.getAllAncestors = function() {
	var p = this.getParentElement();
	var a = [];
	while (p && (p.nodeType == 1) && (p.tagName.toLowerCase() != 'body')) {
		if(p.tagName.toLowerCase() != 'html'){
		a.push(p);
		}
		p = p.parentNode;
	}
	a.push(this._doc.body);
	return a;
};

// Selects the contents inside the given node
HTMLArea.prototype.selectNodeContents = function(node, pos) {
	this.focusEditor();
	this.forceRedraw();
	var range;
	var collapsed = (typeof pos != "undefined");

		var sel = this._getSelection();
		range = this._doc.createRange();
		range.selectNodeContents(node);
		(collapsed) && range.collapse(pos);
		sel.removeAllRanges();
		sel.addRange(range);
};

/** Call this function to insert HTML code at the current position.  It deletes
 * the selection, if any.
 */
HTMLArea.prototype.insertHTML = function(html) {
	var sel = this._getSelection();
	var range = this._createRange(sel);
	if (HTMLArea.is_ie) {
		range.pasteHTML(html);
	} else {
		// construct a new document fragment with the given HTML
		var fragment = this._doc.createDocumentFragment();
		var div = this._doc.createElement("div");
		div.innerHTML = html;
		while (div.firstChild) {
			// the following call also removes the node from div
			fragment.appendChild(div.firstChild);
		}
		// this also removes the selection
		var node = this.insertNodeAtSelection(fragment);
	}
};

/**
 *  Call this function to surround the existing HTML code in the selection with
 *  your tags.  FIXME: buggy!  This function will be deprecated "soon".
 */
HTMLArea.prototype.surroundHTML = function(startTag, endTag) {
	var html = this.getSelectedHTML();
	// the following also deletes the selection
	this.insertHTML(startTag + html + endTag);
};

/// Retrieve the selected block
HTMLArea.prototype.getSelectedHTML = function() {
	var sel = this._getSelection();
	var range = this._createRange(sel);
	var existing = null;
	if (HTMLArea.is_ie) {
		existing = range.htmlText;
	} else {
		existing = HTMLArea.getHTML(range.cloneContents(), false);
	}
	return existing;
};

// Called when the user clicks on "InsertImage" button
HTMLArea.prototype._insertImage = function() {
	var path=fHERE();
	var obj=new Object;
	obj.lang=Lang;
	obj.BASEURL=this.URLBASE;
	var path=path.substr(0,path.length-8);
	var editor = this;	// for nested functions
	
	obj.path=path+this.popupURL("navigator.html");
	this._popupDialog("insert_image.html", function(param) {
		if (!param) {	// user must have pressed Cancel
			return false;
		}
		var sel = editor._getSelection();
		var range = editor._createRange(sel);
		editor._doc.execCommand("insertimage", false, param["f_url"]);
		var img = null;
		if (HTMLArea.is_ie) {
			img = range.parentElement();
			// wonder if this works...
			if (img.tagName.toLowerCase() != "img") {
				img = img.previousSibling;
			}
		} else {
			img = range.startContainer.previousSibling;
		}
		for (field in param) {
			var value = param[field];
			if (!value) {
				continue;
			}
			switch (field) {
			    case "f_alt"    : img.alt	 = value; break;
			    case "f_border" : img.border = parseInt(value); break;
			    case "f_align"  : img.align	 = value; break;
			    case "f_vert"   : img.vspace = parseInt(value); break;
			    case "f_horiz"  : img.hspace = parseInt(value); break;
			}
		}
	}, obj);
};

// Called when the user clicks the Insert Table button
HTMLArea.prototype._insertTable = function() {
	var sel = this._getSelection();
	var range = this._createRange(sel);
	var editor = this;	// for nested functions
	this._popupDialog("insert_table.html", function(param) {
		if (!param) {	// user must have pressed Cancel
			return false;
		}
		
		var doc3 = editor._doc;
		// create the table element
		var table = doc3.createElement("table");
		// assign the given arguments
		for (var field in param) {
			var value = param[field];
			if (!value) {
				continue;
			}
			switch (field) {
			    case "f_width"   : table.style.width = value + param["f_unit"]; break;
			    case "f_align"   : table.align	 = value; break;
			    case "f_border"  : table.border	 = parseInt(value); break;
			    case "f_spacing" : table.cellspacing = parseInt(value); break;
			    case "f_padding" : table.cellpadding = parseInt(value); break;
			}
		}
		var tbody = doc3.createElement("tbody");
		table.appendChild(tbody);
		for (var i = 0; i < param["f_rows"]; ++i) {
			var tr = doc3.createElement("tr");
			tbody.appendChild(tr);
			for (var j = 0; j < param["f_cols"]; ++j) {
				var td = doc3.createElement("td");
				tr.appendChild(td);
				// Mozilla likes to see something inside the cell.
				(HTMLArea.is_gecko) && td.appendChild(doc.createElement("br"));
			}
		}
		if (HTMLArea.is_ie) {
			range.pasteHTML(table.outerHTML);
		} else {
			// insert the table
			editor.insertNodeAtSelection(table);
			
		}
	
		return true;
	}, Lang);
};

/***************************************************
 *  Category: EVENT HANDLERS
 ***************************************************/

// el is reference to the SELECT object
// txt is the name of the select field, as in config.toolbar
HTMLArea.prototype._comboSelected = function(el, txt) {
	this.focusEditor();
	var value = el.options[el.selectedIndex].value;
	switch (txt) {
	    case "fontname": this.execCommand(txt, false, value);break;
	    case "fontsize": this.execCommand(txt, false, value); break;
	    case "formatblock":
		(HTMLArea.is_ie) && (value = "<" + value + ">");
		this.execCommand(txt, false, value);
		break;
	    default:
		// try to look it up in the registered dropdowns
		var dropdown = this.config.customSelects[txt];
		if (typeof dropdown != "undefined") {
			dropdown.action(this);
		} else {
			alert(fMessage("dsmode")+fMessage("combobox") + txt + fMessage("notimplemented"));
		}
	}
};

// the execCommand function (intercepts some commands and replaces them with
// our own implementation)
HTMLArea.prototype.execCommand = function(cmdID, UI, param) {
	var editor = this;	// for nested functions
	this.focusEditor();
	switch (cmdID.toLowerCase()) {
	    case "hilitecolor":
		(HTMLArea.is_ie) && (cmdID = "backcolor");
	    case "forecolor":
		this._popupDialog("select_color.html", function(color) {
			if (color) { // selection not canceled
				editor._doc.execCommand(cmdID, false, "#" + color);
			}
		}, HTMLArea._colorToRgb(this._doc.queryCommandValue(cmdID)));
		break;
	    case "createlink": this.fCreateLink(); break;
	    case "popupeditor":
		if (HTMLArea.is_ie) {
			window.open(this.popupURL("fullscreen.html"), "ha_fullscreen",
				    "toolbar=no,location=no,directories=no,status=no,menubar=no," +
				    "scrollbars=no,resizable=yes,width=640,height=480");
		} else {
			window.open(this.popupURL("fullscreen.html"), "ha_fullscreen",
				    "toolbar=no,menubar=no,personalbar=no,width=640,height=480," +
				    "scrollbars=no,resizable=yes");
		}
		// pass this object to the newly opened window
		HTMLArea._object = this;
		break;
		case "undo": 
		if (this._customUndo)
			this.undo();
		else
			this._doc.execCommand(cmdID, UI, param);
		break;
	    case "redo":
		if (this._customUndo)
			this.redo();
		else
			this._doc.execCommand(cmdID, UI, param);
		break;
		case "subscript":
			var cas;
			for (var i in this._toolbarObjects) {
				var btn = this._toolbarObjects[i];
				if(btn.name=="superscript") cas=btn.active;	
			}
			
			if(cas){
				this._doc.execCommand("superscript", UI, param);
				this._doc.execCommand(cmdID, UI, param);
				break;
			}
			this._doc.execCommand(cmdID, UI, param);
			break;
		case "superscript": 
			var cas;
			for (var i in this._toolbarObjects) {
				var btn = this._toolbarObjects[i];
				if(btn.name=="subscript") cas=btn.active;	
			}
			
			if(cas){
				this._doc.execCommand("subscript", UI, param);
				this._doc.execCommand(cmdID, UI, param);
				break;
			}
			this._doc.execCommand(cmdID, UI, param);
			break;
	    case "inserttable": this._insertTable(); break;
	    case "insertimage": this._insertImage(); break;
	    case "about"    : this._popupDialog("about.html", null, null); break;
	    case "showhelp" : window.open("reference.html", "ha_help"); break;
	    case "insertform" : this.sInsertForm(); break;
	    case "inserttextfield" : this.sFormTextField(); break;
	    case "inserttextarea" : this.sFormTextArea(); break;
	    case "insertbutton" : this.sFormButton(); break;
	    case "insertsubmit" : this.sFormSubmit(); break;
	    case "insertcheck" : this.sFormCheck(); break;
	    case "insertradio" : this.sFormRadio(); break;
	    case "insertdropdown" : this.sFormDropdown(); break;
	    case "inserthidden" : this.sFormHidden(); break;
	    case "selectall" : this.sSelectAll(); break;
	    case "htmlmode" : this.setMode("html"); break;
	    case "dsmode" : this.setMode("wysiwyg"); break;
	    case "prvmode" : this.setMode("preview"); break;
	    case "insertsymbol" : this.InsSymbols(); break;
	    case "tagedit" : this.TagEdit(); break;
	    case "tagprop" : this.TagProperty(); break;
	    case "tagstl" : this.TagStl(); break;
	    case "finde" : this.fFinde(); break;
	    case "cleansel" : this.fCleanSel(); break;
	    case "cleansel1" : this.fCleanSel1(); break;
	    case "cleansel2" : this.fCleanSel2(); break;
	    case "deltag" : this.fDelTag(); break;
	    case "spell" : this.fSpell(); break;
	    case "fullscreen" : this.fFullscreen(); break;
	    case "fontname" :
	    var str=this.getSelectedHTML();
	    var str1;
	    if(str!=""){
			var f=false;
			var e=false;
			if(/<font(.*?)>/gim.test(str)) f=true;
			if(/<\/font>/gim.test(str)) e=true;
			if(!f && !e){
				str1='<font style="font-family: ' + param + ';">' + str + '</font>';
			}else if(f && e){
				str=str.replace(/<font(.*?)>/gim,'');
				str=str.replace('</font>','');
				str1='<font style="font-family: ' + param + ';">' + str + '</font>';
			}else if(!f && e){
				str=str.replace('</font>','');
				str1='</font><font style="font-family: ' + param + ';">' + str + '</font>';
			}else if(f && !e){
				var rt=str.match(/<font(.*?)>/gim);
				str=str.replace(/<font(.*?)>/gim,'');
				str1='<font style="font-family: ' + param + ';">' + str + '</font>'+ rt[0];
			}
			this.insertHTML(str1);
	    }
	    break;
	    case "shbord" : 
			this.fShowBorders(); 
			if(editor.showborders==true){
				HTMLArea._addClass(elb, "buttonPressed");
			}else{
				HTMLArea._removeClass(elb, "buttonPressed");
			}
			break;
	    case "shscr" : 
			this.fShowScripts(); 
			if(editor.showscripts==true){
				HTMLArea._addClass(els, "buttonPressed");
			}else{
				HTMLArea._removeClass(els, "buttonPressed");
			}
			break;
	    default: this._doc.execCommand(cmdID, UI, param);
	}
	
	
	this.updateToolbar();
	return false;
};

	
HTMLArea.prototype.fCreateLink = function() {		

var link=null;
var editor = this;
var obj=new Object;
	var outparam = null;
	var an=editor.getAllAncestors();
	if (an[0].tagName.toLowerCase()=="a") link=an[0];
	if (link) outparam = {
		f_href   : link.getAttribute("href"),
		f_title  : link.title,
		f_target : link.target
		};
	obj.param=	outparam;
	obj.lang= Lang; 
	this._popupDialog("link.html", function(param) {
		if (!param)
			return false;
		var a = link;
		if (!a) {
			var a=editor._doc.createElement("a");
			var sel = editor._getSelection();
			var range = editor._createRange(sel);
			var text=range.toString();
			
			if(text){
				a.innerHTML=text;
			}else{
				a.innerHTML=param.f_href;
			}
			a.href = param.f_href;
			a.target = param.f_target;
			a.title = param.f_title;
			editor.insertNodeAtSelection(a);

		} else a.href = param.f_href;//;
		a.target = param.f_target;//.trim();
		a.title = param.f_title;//.trim();
		editor.selectNodeContents(a);
		editor.updateToolbar();
	}, obj);
};

HTMLArea.prototype.fCleanSel = function() {

var an = editor.getAllAncestors();
var el=an[0];
if(el.id.toLowerCase() == "asp" || el.id.toLowerCase() == "php" || el.id.toLowerCase() == "script"){
alert("Not Allowed Operation");
}else{
	var html=el.innerHTML;
	html=html.replace('</div>','');
	html=html.replace('</p>','');
	html=html.replace('</td>','');
	html=html.replace('</tr>','');
	html=html.replace('</font>','');
	html=html.replace('</sub>','');
	html=html.replace('</sup>','');
	html=html.replace('</strike>','');
	html=html.replace('</u>','');
	html=html.replace('</em>','');
	html=html.replace('</strong>','');
	html=html.replace('</center>','');
	html=html.replace('</ol>','');
	html=html.replace('</li>','');
	html=html.replace('</a>','');
	html=html.replace('</ul>','');
	html=html.replace('</h1>','');
	html=html.replace('</h2>','');
	html=html.replace('</h3>','');
	html=html.replace('</h4>','');
	html=html.replace('</h5>','');
	html=html.replace('</h6>','');
	html=html.replace('</tbody>','');
	html=html.replace('</table>','');
	html=html.replace('</span>','');
	html=html.replace('</blockquote>','');
	html=html.replace('</q>','');
	html=html.replace('</i>','');
	html=html.replace('</b>','');
	
	html=html.replace(/<div([\s\S]*?)>/gim,'');
	html=html.replace(/<p([\s\S]*?)>/gim,'');
	html=html.replace(/<td([\s\S]*?)>/gim,'');
	html=html.replace(/<tr([\s\S]*?)>/gim,'');
	html=html.replace(/<font([\s\S]*?)>/gim,'');
	html=html.replace(/<sub([\s\S]*?)>/gim,'');
	html=html.replace(/<sup([\s\S]*?)>/gim,'');
	html=html.replace(/<strike([\s\S]*?)>/gim,'');
	html=html.replace(/<u([\s\S]*?)>/gim,'');
	html=html.replace(/<em([\s\S]*?)>/gim,'');
	html=html.replace(/<strong([\s\S]*?)>/gim,'');
	html=html.replace(/<center([\s\S]*?)>/gim,'');
	html=html.replace(/<ol([\s\S]*?)>/gim,'');
	html=html.replace(/<li([\s\S]*?)>/gim,'');
	html=html.replace(/<a([\s\S]*?)>/gim,'');
	html=html.replace(/<ul([\s\S]*?)>/gim,'');
	html=html.replace(/<h1([\s\S]*?)>/gim,'');
	html=html.replace(/<h2([\s\S]*?)>/gim,'');
	html=html.replace(/<h3([\s\S]*?)>/gim,'');
	html=html.replace(/<h4([\s\S]*?)>/gim,'');
	html=html.replace(/<h5([\s\S]*?)>/gim,'');
	html=html.replace(/<h6([\s\S]*?)>/gim,'');
	html=html.replace(/<tbody([\s\S]*?)>/gim,'');
	html=html.replace(/<table([\s\S]*?)>/gim,'');
	html=html.replace(/<img([\s\S]*?)>/gim,'');
	html=html.replace(/<span([\s\S]*?)>/gim,'');
	html=html.replace(/<blockquote([\s\S]*?)>/gim,'');
	html=html.replace(/<q([\s\S]*?)>/gim,'');
	html=html.replace(/<i([\s\S]*?)>/gim,'');
	html=html.replace(/<b([\s\S]*?)>/gim,'');
	el.innerHTML=html;
}
};

HTMLArea.prototype.fCleanSel1 = function() {
var an = editor.getAllAncestors();
var el=an[0];
if(el.id.toLowerCase() == "asp" || el.id.toLowerCase() == "php" || el.id.toLowerCase() == "script"){
	alert("Not Allowed Operation");
}else{
	var html=el.innerHTML;
	html=html.replace('</div>','');
	html=html.replace('</td>','');
	html=html.replace('</tr>','');
	html=html.replace('</font>','');
	html=html.replace('</sub>','');
	html=html.replace('</sup>','');
	html=html.replace('</strike>','');
	html=html.replace('</center>','');
	html=html.replace('</ol>','');
	html=html.replace('</li>','');
	html=html.replace('</ul>','');
	html=html.replace('</h5>','');
	html=html.replace('</h6>','');
	html=html.replace('</tbody>','');
	html=html.replace('</table>','');
	html=html.replace('</span>','');
	html=html.replace('</blockquote>','');
	html=html.replace('</q>','');
	
	html=html.replace(/<div([\s\S]*?)>/gim,'');
	html=html.replace(/<td([\s\S]*?)>/gim,'');
	html=html.replace(/<tr([\s\S]*?)>/gim,'');
	html=html.replace(/<font([\s\S]*?)>/gim,'');
	html=html.replace(/<sub([\s\S]*?)>/gim,'');
	html=html.replace(/<sup([\s\S]*?)>/gim,'');
	html=html.replace(/<strike([\s\S]*?)>/gim,'');
	html=html.replace(/<center([\s\S]*?)>/gim,'');
	html=html.replace(/<ol([\s\S]*?)>/gim,'');
	html=html.replace(/<li([\s\S]*?)>/gim,'');
	html=html.replace(/<ul([\s\S]*?)>/gim,'');
	html=html.replace(/<h5([\s\S]*?)>/gim,'');
	html=html.replace(/<h6([\s\S]*?)>/gim,'');
	html=html.replace(/<tbody([\s\S]*?)>/gim,'');
	html=html.replace(/<table([\s\S]*?)>/gim,'');
	html=html.replace(/<span([\s\S]*?)>/gim,'');
	html=html.replace(/<blockquote([\s\S]*?)>/gim,'');
	html=html.replace(/<q([\s\S]*?)>/gim,'');
	el.innerHTML=html;
}
};

HTMLArea.prototype.fCleanSel2 = function() {
var an = editor.getAllAncestors();
var el=an[0];
if(el.id.toLowerCase() == "asp" || el.id.toLowerCase() == "php" || el.id.toLowerCase() == "script"){
alert("Not Allowed Operation");
}else{
	var html=el.innerHTML;
	html=html.replace('</div>','');
	html=html.replace('</font>','');
	html=html.replace('</sub>','');
	html=html.replace('</sup>','');
	html=html.replace('</strike>','');
	html=html.replace('</h6>','');
	html=html.replace('</span>','');
	
	html=html.replace(/<div([\s\S]*?)>/gim,'');
	html=html.replace(/<font([\s\S]*?)>/gim,'');
	html=html.replace(/<sub([\s\S]*?)>/gim,'');
	html=html.replace(/<sup([\s\S]*?)>/gim,'');
	html=html.replace(/<strike([\s\S]*?)>/gim,'');
	html=html.replace(/<h6([\s\S]*?)>/gim,'');
	html=html.replace(/<span([\s\S]*?)>/gim,'');
	el.innerHTML=html;
}
};

HTMLArea.prototype.fDelTag = function() {
var an = editor.getAllAncestors();
var el=an[0];
if(el.tagName.toLowerCase() == 'body' || el.id.toLowerCase() == "asp" || el.id.toLowerCase() == "php" || el.id.toLowerCase() == "script"){
alert(fMessage("notallowedoperation"));
}else{
	var html=el.innerHTML;
	an[1].removeChild(el);
	editor.insertHTML(html);
}
};

HTMLArea.prototype.fShowBorders = function() {
if(editor.showborders==true){
	editor.showborders=false;
}else{
	editor.showborders=true;
}
mvContent=setBody(HTMLArea.getHTML(this._doc.body, false));
initIframe();
};

HTMLArea.prototype.fShowScripts = function() {
if(editor.showscripts==true){
	editor.showscripts=false;
}else{
	editor.showscripts=true;
}
		mvContent=setBody(HTMLArea.getHTML(this._doc.body, false));
		initIframe();
	
};
/** A generic event handler for things that happen in the IFRAME's document.
 * This function also handles key bindings. */
HTMLArea.prototype._editorEvent = function(ev) {
if(ev.type == "focus"){

	var str=this.getSelectedHTML()
	if(str.match(/<td/gim)||str.match(/<tr/gim)||str.match(/<img/gim)){
	
	}else{
		if(str.match(/<[select|input]/gim)){
			this.insertHTML(str);
		}
	}
HTMLArea._stopEvent(ev);
}else{

	var editor = this;
	var keyEvent = (HTMLArea.is_ie && ev.type == "keydown") || (ev.type == "keypress");
	if (keyEvent && ev.ctrlKey) {
		var sel = null;
		var range = null;
		var key = String.fromCharCode(HTMLArea.is_ie ? ev.keyCode : ev.charCode).toLowerCase();
		var cmd = null;
		var value = null;
		switch (key) {
		    case 'a':
			if (!HTMLArea.is_ie) {
				// KEY select all
				sel = this._getSelection();
				sel.removeAllRanges();
				range = this._createRange();
				range.selectNodeContents(this._doc.body);
				sel.addRange(range);
				HTMLArea._stopEvent(ev);
			}
			break;

			// simple key commands follow

		    case 'b': cmd = "bold"; break;
		    case 'i': cmd = "italic"; break;
		    case 'u': cmd = "underline"; break;
		    case 's': cmd = "strikethrough"; break;
		    case 'l': cmd = "justifyleft"; break;
		    case 'e': cmd = "justifycenter"; break;
		    case 'r': cmd = "justifyright"; break;
		    case 'j': cmd = "justifyfull"; break;
		    case 'z': cmd = "undo"; break;
		    case 'y': cmd = "redo"; break;

			// headings
		    case '1':
		    case '2':
		    case '3':
		    case '4':
		    case '5':
		    case '6':
			cmd = "formatblock";
			value = "h" + key;
			if (HTMLArea.is_ie) {
				value = "<" + value + ">";
			}
			break;
		}
		if (cmd) {
			// execute simple command
			this.execCommand(cmd, false, value);
			HTMLArea._stopEvent(ev);
		}
	
	}
	/*
	else if (keyEvent) {
		// other keys here
		switch (ev.keyCode) {
		    case 13: // KEY enter
			// if (HTMLArea.is_ie) {
			this.insertHTML("<br />");
			HTMLArea._stopEvent(ev);
			// }
			break;
		}
	}
	*/
	
	// update the toolbar state after some time
	if (editor._timerToolbar) {
		clearTimeout(editor._timerToolbar);
	}
	editor._timerToolbar = setTimeout(function() {
		editor.updateToolbar();
		editor._timerToolbar = null;
	}, 50);
	}
};

// retrieve the HTML
HTMLArea.prototype.getHTML = function() {
	switch (this._editMode) {
	    case "wysiwyg"  :
			if(mvMode=="html"){
				return setBody(this._doc.body.innerHTML);//return setBody(HTMLArea.getHTML(this._doc.body, false));
			}else{
				return getBody(mvContent);
			}
			break;
	    case "html" : 
			mvContent=this._textArea.value;
			if(mvMode=="html"){
				return mvContent;
			}else{
				return getBody(this._textArea.value);
			}
			break;
	    case "preview"  : 
			if(mvMode=="html"){
				return mvContent;
			}else{
				return getBody(mvContent);
			}
			break;
	    default	    : alert(fMessage("mode") + this._editMode  + fMessage("notdefined"));
	}
	return false;
};

HTMLArea.prototype.getHTMLOut = function() { 
 var htmlsource=""; 
switch (this._editMode) {
	    case "wysiwyg"  : htmlsource=setBody(this._doc.body.innerHTML); break;//setBody(HTMLArea.getHTML(this._doc.body, false));
	    case "html" : htmlsource=this._textArea.value; break;
	    case "preview"  : htmlsource=mvContent; break;
	    default	    : alert(fMessage("mode") + this._editMode  + fMessage("notdefined"));
  }
 return htmlsource; 
};


// retrieve the HTML (fastest version, but uses innerHTML)
HTMLArea.prototype.getInnerHTML = function() {
	switch (this._editMode) {
	    case "wysiwyg"  :
			if(this._doc.body){
				return setBody(this._doc.body.innerHTML);//return setBody(HTMLArea.getHTML(this._doc.body, false));
			}else{
				return getBody(mvContent);
			}
			break;
	    case "html" : 
			mvContent=this._textArea.value;
			if(mvMode=="html"){
				return mvContent;
			}else{
				return getBody(this._textArea.value);
			}
			break;
	    case "preview"  : 
			if(mvMode=="html"){
				return mvContent;
			}else{
				return getBody(mvContent);
			}
			break;
	    default	    : alert(fMessage("mode") + this._editMode  + fMessage("notdefined"));
	}
	return false;
};

// completely change the HTML inside
HTMLArea.prototype.setHTML = function(html, AURL) {

vURL=AURL;
f="";
if(vURL && vURL!="" && typeof vURL!="undefined"){
	f= '<BASE href="' + vURL + '">';
}
	var valHTM;
	switch (this._editMode) {
	    case "wysiwyg"  : 
	    if(this._doc.body !=null){
			this._doc.body.innerHTML=getBody(html);
	    }
	    break;
	    case "html" : this._textArea.value = setBody(html); break;
	    case "preview"  : this._doc.body.innerHTML=getBody(html);break;
	    default	    : alert("Mode <" + mode + "> not defined!");
	}
	return false;
};



function delHref(html){


if(editor.base=="" || typeof editor.base == "undefined"){
	return html;
}else{
	return html.substr(editor.base.length,html.length-editor.base.length);
}
}

function getBody(html){
mvContent=html;
var bodytag;  
var re=/<body([\s\S]*?)<\/body>/gim;
var L1;
var t;
t=html.match(re);

if(t){
	bodytag=re.exec(html);
	var L=bodytag.index;
	var R=bodytag[0].length+L;
	var D=html.length;

	if(L==0){ 
		  L=0 ; R=D;
	}else{

		  for(var i=L;i<R;i++){
			if(html.substr(i,1)==">"){
				L1=i+1;
				break;
			}
		}
     
		L=L1;
		R1=R-7;
		R=R1;
		if(R==0){ 
			R=D;
		}
	}
	
	vFirst=html.substr(0, L);
	vLast=html.substr(R, D-R);
	editor.first=vFirst;
	editor.bod=fAddVT(html.substr(L, R-L));
	return fAddVT(html.substr(L, R-L));
}else{
	editor.bod=fAddVT(html);
	return fAddVT(html);
}
};

var f;
function setBody(html){

if(vFirst && vFirst!="" && typeof vFirst!="undefined"){
	
}else{
vFirst="";
}

if(vLast && vLast!="" && typeof vLast!="undefined"){
	
}else{
vLast="";
}

return vFirst+fRemoveVT(html)+vLast;
};

function fAddVT(html){
var vt, vt1, vt2, vt3, ht;
var imgstyle;

if(editor.showscripts==true){ 
	imgstyle="";
}else{
	imgstyle=" style='border:none;height:0px;width:0px;' ";
}

var ht;
ht=/<input(.*?)type=([\"|\'])hidden([\"|\'])(.*?)>/gim;
var ht1=/<input(.*?)type=hidden(.*?)>/gim;
var htcont;
try{
htcont=html.match(ht);
}catch(e){
}
for (var i in htcont) {
			var tmp=htcont[i];
			tmp=tmp.replace('type="hidden"','type="text"');
			tmp=tmp.replace("type='hidden'",'type="text"');
			tmp=tmp.replace('type=hidden','type="text"');
			var tmp1=tmp.substr(0,tmp.length-1);
			tmp=tmp1+' plshidden="hidden">';
			html=html.replace(htcont[i],tmp);
}
try{
htcont=html.match(ht1);
}catch(e){
}
for (var i in htcont) {
			var tmp=htcont[i];
			tmp=tmp.replace('type="hidden"','type="text"');
			tmp=tmp.replace("type='hidden'",'type="text"');
			tmp=tmp.replace('type=hidden','type="text"');
			var tmp1=tmp.substr(0,tmp.length-1);
			tmp=tmp1+' plshidden="hidden">';
			html=html.replace(htcont[i],tmp);
}


vt=/<[A-Za-z]+?(\s\S[^<>]*?)<[\?|%]([\s\S]*?)[\?|%]>([\s\S]*?)>/gim;
var convt;
var convt1;
var convt2;
var convt3;
var i, j;
vt1=/<(%)([\s\S]*?)(%)>/gim;
vt2=/<(\?)([\s\S]*?)(\?)>/gim;
vt3=/<SCRIPT([\s\S]*?)>[\s\S]*?<\/SCRIPT>/gim;
try{
convt=html.match(vt);
}catch(e){
}

for (var i in convt) {
	convt1=convt[i].match(vt1);
	if(convt1 != null){
		for (var j in convt1) {
			var st=escape(convt1[j].substr(2,convt1[j].length-4));
			html=html.replace(convt[i],convt[i].replace(convt1[j],"[DIGI_SSTASPO"+st+"DIGI_SSTASPC"));
		}
	}
}

for (var i in convt) {
	convt2=convt[i].match(vt2);
	if(convt2 != null){
		for (var j in convt2) {
			var st=escape(convt2[j].substr(2,convt2[j].length-4));
			html=html.replace(convt[i],convt[i].replace(convt2[j],"[DIGI_SSTPHPO"+st+"DIGI_SSTPHPC"));
		}
	}
}

try{
	convt1=html.match(vt1);
}catch(e){
}

for (var i in convt1) {

	var st=escape(convt1[i].substr(2,convt1[i].length-4));
	html=html.replace(convt1[i],"<img src='"+fHERE()+editor.imgURL("img/")+"ASP.gif'" + imgstyle + "id=ASP asp='[DIGI_ASPO"+ st +"DIGI_ASPC]'>");
}

try{
	convt2=html.match(vt2);
}catch(e){
}

for (var i in convt2) {

	var st=escape(convt2[i].substr(2,convt2[i].length-4));
	html=html.replace(convt2[i],"<img src='"+fHERE()+editor.imgURL("img/")+"PHP.gif'" + imgstyle + "id=PHP php='[DIGI_PHPO"+ st +"DIGI_PHPC]'>");
}

try{
	convt3=html.match(vt3);
}catch(e){
}

for (var i in convt3) {

	var st=escape(convt3[i]);
	html=html.replace(convt3[i],"<img src='"+fHERE()+editor.imgURL("img/")+"SCRIPT.gif'" + imgstyle + "id=SCRIPT script='[DIGI_SCRIPTO"+ st +"DIGI_SCRIPTC]'>");
}

return html;
};

function fRemoveVT(html){
var vt1, vt2, vt3, vt4, vt5, vt6, vt7, vt8;
var ht;
ht=/<input(.*?)plshidden=\"hidden\"(.*?)>/gim;
var htcont;
try{
htcont=html.match(ht);
}catch(e){
}
for (var i in htcont) {
			var tmp=htcont[i];
			tmp=tmp.replace('type="text"','type="hidden"');
			tmp=tmp.replace("type='text'",'type="hidden"');
			tmp=tmp.replace('type=text','type="hidden"');
			tmp=tmp.replace('plshidden="hidden"','');
			html=html.replace(htcont[i],tmp);
}

var convt1, convt2, convt3, convt4, convt5, convt6, convt7, convt8;
vt1=/<(img)([\s\S]*?)(\">|\'>)/gim;
vt2=/\[DIGI_ASPO([\s\S]*?)DIGI_ASPC\]/gim;
vt3=/<(img)([\s\S]*?)(\">|\'>)/gim;
vt4=/\[DIGI_PHPO([\s\S]*?)DIGI_PHPC\]/gim;
vt5=/<(img)([\s\S]*?)(\">|\'>)/gim;
vt6=/\[DIGI_SCRIPTO([\s\S]*?)DIGI_SCRIPTC\]/gim;
vt7=/(\[DIGI_SSTASPO)([\s\S]*?)(DIGI_SSTASPC\=\"\")/gim;
vt8=/(\[DIGI_SSTPHPO)([\s\S]*?)(DIGI_SSTPHPC\=\"\")/gim;

convt1=html.match(vt1);
for (var i in convt1) {
	convt2=convt1[i].match(vt2);
	for (var j in convt2) {
		var st=unescape(convt2[j]);
		st=st.replace("[DIGI_ASPO","<%");
		st=st.replace("DIGI_ASPC]","%>");
		html=html.replace(convt1[i],st);
	}
}

convt3=html.match(vt3);
for (var i in convt3) {
	convt4=convt3[i].match(vt4);
	for (var j in convt4) {
		var st=unescape(convt4[j]);
		st=st.replace("[DIGI_PHPO","<?");
		st=st.replace("DIGI_PHPC]","?>");
		html=html.replace(convt3[i],st);
	}
}

convt5=html.match(vt5);
for (var i in convt5) {
	convt6=convt5[i].match(vt6);
	for (var j in convt6) {
		var st=unescape(convt6[j]);
		st=st.replace("[DIGI_SCRIPTO","");
		st=st.replace("DIGI_SCRIPTC]","");
		html=html.replace(convt5[i],st);
	}
}

convt7=html.match(vt7);
for (var i in convt7) {
	var st=unescape(convt7[i]);
	st=st.replace("[digi_sstaspo", "<%");
	st=st.replace('digi_sstaspc=""', "%>");
	html=html.replace(convt7[i],st);
}

convt8=html.match(vt8);
for (var i in convt8) {
	var st=unescape(convt8[i]);
	st=st.replace("[digi_sstphpo", "<?");
	st=st.replace('digi_sstphpc=""', "?>");
	html=html.replace(convt8[i],st);
}

return html;
};


//return vFirst+html+vLast;delHref(

/***************************************************
 *  Category: UTILITY FUNCTIONS
 ***************************************************/

// browser identification

HTMLArea.agt = navigator.userAgent.toLowerCase();
HTMLArea.is_ie	   = ((HTMLArea.agt.indexOf("msie") != -1) && (HTMLArea.agt.indexOf("opera") == -1));
HTMLArea.is_opera  = (HTMLArea.agt.indexOf("opera") != -1);
HTMLArea.is_mac	   = (HTMLArea.agt.indexOf("mac") != -1);
HTMLArea.is_mac_ie = (HTMLArea.is_ie && HTMLArea.is_mac);
HTMLArea.is_win_ie = (HTMLArea.is_ie && !HTMLArea.is_mac);
HTMLArea.is_gecko  = (navigator.product == "Gecko");

// variable used to pass the object to the popup editor window.
HTMLArea._object = null;

// FIXME!!! this should return false for IE < 5.5
HTMLArea.checkSupportedBrowser = function() {
	if (HTMLArea.is_gecko) {
		if (navigator.productSub < 20021201) {
			alert(fMessage("mozilla13") + fMessage("sorrygecko"));
			return false;
		}
		if (navigator.productSub < 20030210) {
			alert(fMessage("mozilla13beta") + fMessage("trynotwork"));
		}
	}
	return HTMLArea.is_gecko || HTMLArea.is_ie;
};

// selection & ranges

// returns the current selection object
HTMLArea.prototype._getSelection = function() {
	if (HTMLArea.is_ie) {
		return this._doc.selection;
	} else {
		return this._iframe.contentWindow.getSelection();
	}
};

// returns a range for the current selection
HTMLArea.prototype._createRange = function(sel) {
	if (HTMLArea.is_ie) {
		return sel.createRange();
	} else {
		this.focusEditor();
		if (typeof sel != "undefined") {
				return sel.getRangeAt(0);
		} else {
			return this._doc.createRange();
		}
	}
};

// event handling

HTMLArea._addEvent = function(el, evname, func) {
	if (HTMLArea.is_ie) {
		el.attachEvent("on" + evname, func);
	} else {
		el.addEventListener(evname, func, true);
	}
};

HTMLArea._addEvents = function(el, evs, func) {
	for (var i in evs) {
		HTMLArea._addEvent(el, evs[i], func);
	}
};

HTMLArea._removeEvent = function(el, evname, func) {
	if (HTMLArea.is_ie) {
		el.detachEvent("on" + evname, func);
	} else {
		el.removeEventListener(evname, func, true);
	}
};

HTMLArea._removeEvents = function(el, evs, func) {
	for (var i in evs) {
		HTMLArea._removeEvent(el, evs[i], func);
	}
};

HTMLArea._stopEvent = function(ev) {
	if (HTMLArea.is_ie) {
		ev.cancelBubble = true;
		ev.returnValue = false;
	} else {
		ev.preventDefault();
		ev.stopPropagation();
	}
};

HTMLArea._removeClass = function(el, className) {
	if (!(el && el.className)) {
		return;
	}
	var cls = el.className.split(" ");
	var ar = new Array();
	for (var i = cls.length; i > 0;) {
		if (cls[--i] != className) {
			ar[ar.length] = cls[i];
		}
	}
	el.className = ar.join(" ");
};

HTMLArea._addClass = function(el, className) {
	// remove the class first, if already there
	HTMLArea._removeClass(el, className);
	el.className += " " + className;
};

HTMLArea._hasClass = function(el, className) {
	if (!(el && el.className)) {
		return false;
	}
	var cls = el.className.split(" ");
	for (var i = cls.length; i > 0;) {
		if (cls[--i] == className) {
			return true;
		}
	}
	return false;
};

HTMLArea.isBlockElement = function(el) {
	var blockTags = " body form textarea fieldset ul ol dl li div " +
		"p h1 h2 h3 h4 h5 h6 quote pre table thead " +
		"tbody tfoot tr td iframe address ";
	return (blockTags.indexOf(" " + el.tagName.toLowerCase() + " ") != -1);
};

HTMLArea.needsClosingTag = function(el) {
	var closingTags = " script style div span tr td tbody table em strong font a ";
	return (closingTags.indexOf(" " + el.tagName.toLowerCase() + " ") != -1);
};

// performs HTML encoding of some given string
HTMLArea.htmlEncode = function(str) {
	// we don't need regexp for that, but.. so be it for now.
	//str = str.replace(/&/ig, "&amp;");
	//str = str.replace(/</ig, "&lt;");
	//str = str.replace(/>/ig, "&gt;");
	//str = str.replace(/\x22/ig, "&quot;");
	// \x22 means '"' -- we use hex reprezentation so that we don't disturb
	// JS compressors (well, at least mine fails.. ;)
	return str;
};

// Retrieves the HTML code from the given node.	 This is a replacement for
// getting innerHTML, using standard DOM calls.
HTMLArea.getHTML = function(root, outputRoot) {
	var html = "";
	
	switch (root.nodeType) {
	    case 1: // Node.ELEMENT_NODE
	    case 11: // Node.DOCUMENT_FRAGMENT_NODE
		var closed;
		var i;
		if (outputRoot) {
			closed = (!(root.hasChildNodes() || HTMLArea.needsClosingTag(root)));
			html = "<" + root.tagName.toLowerCase();
			var attrs = root.attributes;
			for (i = 0; i < attrs.length; ++i) {
				var a = attrs.item(i);
				if (!a.specified) {
					continue;
				}
				var name = a.nodeName.toLowerCase();
				if (/_moz/.test(name)) {
					// Mozilla reports some special tags
					// here; we don't need them.
					continue;
				}
				var value;
				if (name != "style") {
					// IE5.5 reports 25 when cellSpacing is
					// 1; other values might be doomed too.
					// For this reason we extract the
					// values directly from the root node.
					// I'm starting to HATE JavaScript
					// development.  Browser differences
					// suck.
					try{
					if (typeof root[a.nodeName] != "undefined") {
						value = root[a.nodeName];
					} else {
						value = a.nodeValue;
					}
					}catch(e){
						value = a.nodeValue;
					}
				} else { // IE fails to put style in attributes list
					// FIXME: cssText reported by IE is UPPERCASE
					value = root.style.cssText;
				}
				if (/_moz/.test(value)) {
					// Mozilla reports some special tags
					// here; we don't need them.
					continue;
				}
				html += " " + name + '="' + value + '"';
			}
			
			if(root.tagName.toLowerCase()=="base" || root.tagName.toLowerCase()=="input" || root.tagName.toLowerCase()=="textarea" || root.tagName.toLowerCase()=="option" || root.tagName.toLowerCase()=="img" || root.tagName.toLowerCase()=="br"){
				html += ">";
			}else{
				html += closed ? " />" : ">";
			}
		}
		for (i = root.firstChild; i; i = i.nextSibling) {
			html += HTMLArea.getHTML(i, true);
		}
		if (outputRoot && !closed) {
			html += "</" + root.tagName.toLowerCase() + ">";
		}
		break;
	    case 3: // Node.TEXT_NODE
		html = HTMLArea.htmlEncode(root.data);
		
		if(root.data != "" && root.data != "\n"){
		arrData[idd]=root;
		arrElement[idd]=root.parentNode;
		idd++;
		}
		break;
	    case 8: // Node.COMMENT_NODE
		html = "<!--" + root.data + "-->";
		break;		// skip comments, for now.
		
	}
	return html;
};

var idd=0;
var arrData=new Array;
var arrElement=new Array;


// creates a rgb-style color from a number
HTMLArea._makeColor = function(v) {
	if (typeof v != "number") {
		// already in rgb (hopefully); IE doesn't get here.
		return v;
	}
	// IE sends number; convert to rgb.
	var r = v & 0xFF;
	var g = (v >> 8) & 0xFF;
	var b = (v >> 16) & 0xFF;
	return "rgb(" + r + "," + g + "," + b + ")";
};

// returns hexadecimal color representation from a number or a rgb-style color.
HTMLArea._colorToRgb = function(v) {
	// returns the hex representation of one byte (2 digits)
	function hex(d) {
		return (d < 16) ? ("0" + d.toString(16)) : d.toString(16);
	};

	if (typeof v == "number") {
		// we're talking to IE here
		var r = v & 0xFF;
		var g = (v >> 8) & 0xFF;
		var b = (v >> 16) & 0xFF;
		return "#" + hex(r) + hex(g) + hex(b);
	}

	if (v.substr(0, 3) == "rgb") {
		// in rgb(...) form -- Mozilla
		var re = /rgb\s*\(\s*([0-9]+)\s*,\s*([0-9]+)\s*,\s*([0-9]+)\s*\)/;
		if (v.match(re)) {
			var r = parseInt(RegExp.$1);
			var g = parseInt(RegExp.$2);
			var b = parseInt(RegExp.$3);
			return "#" + hex(r) + hex(g) + hex(b);
		}
		// doesn't match RE?!  maybe uses percentages or float numbers
		// -- FIXME: not yet implemented.
		return null;
	}

	if (v[0] == "#") {
		// already hex rgb (hopefully :D )
		return v;
	}

	// if everything else fails ;)
	return null;
};

// modal dialogs for Mozilla (for IE we're using the showModalDialog() call).

// receives an URL to the popup dialog and a function that receives one value;
// this function will get called after the dialog is closed, with the return
// value of the dialog.

HTMLArea.prototype.InsSymbols = function() {
	this._popupDialog("special.html", function(symbol) {
			if (symbol) { // selection not canceled
				editor.insertHTML(symbol);
			}
		}, null);
};
HTMLArea.prototype.getParentElement1 = function() {
	var sel = this._getSelection();
	var range = this._createRange(sel);
	if (HTMLArea.is_ie) {
		return range.parentElement ? range.parentElement() : this._doc.body;
	} else {
		var p = range.commonAncestorContainer;
		while (p.nodeType == 1) {
			p = p.parentNode;
		}
		return p;
	}
};



HTMLArea.prototype.TagProperty = function() {
var ancestors = editor.getAllAncestors();
var el=ancestors[0];
if(el.tagName.toLowerCase()=="li" || el.tagName.toLowerCase()=="option"){
	el=el.parentNode;
}
var s="";
var f_lval1,f_ltext,f_lval,f_ta_value, f_cols, f_rows,f_name, f_char, f_valign, f_rules,f_padding,f_spacing,f_summary,f_caption, f_frames, f_action, f_method, f_title, f_value, f_type, f_size, f_ml, f_checked, f_lt, f_target, f_text, f_alt, f_width, f_unit, f_height, f_borders, f_align, f_src, f_face;
var dialog = new PopupWin(editor, fMessage("tagproperties"), function(dialog, params) {
	if(el.tagName.toLowerCase()=="table" || el.tagName.toLowerCase()=="tr"  || el.tagName.toLowerCase()=="td"){
		editor.processStyleTab(params, el);
	}
	var cr=0;
	var cr1=0;
	var Arr=new Array;
	var Arr1=new Array;
		for (var i in params) {
		var val = params[i];
			switch (i) {
			case "f_caption":
				if (/\S/.test(val)) {
					// contains non white-space characters
					var caption = el.getElementsByTagName("caption")[0];
					if (!caption) {
						caption = dialog.editor._doc.createElement("caption");
						el.insertBefore(caption, el.firstChild);
					}
					caption.innerHTML = val;
				} else {
					// search for caption and delete it if found
					var caption = el.getElementsByTagName("caption")[0];
					if (caption) {
						caption.parentNode.removeChild(caption);
					}
				}
				break;
			case "f_summary":
				el.summary = val;
				break;
			case "f_spacing":
				el.cellSpacing = val;
				break;
			case "f_padding":
				el.cellPadding = val;
				break;
			case "f_frames":
				el.frame = val;
				break;
			case "f_rules":
				el.rules = val;
				break;
			case "f_name":
				el.name=val;
				break;
			case "f_action":
				el.action=val;
				break;
			case "f_method":
				el.method=val;
				break;
			case "f_title":
				el.title=val;
				break;
			case "f_value":
				el.value=val;
				break;
			case "f_size":
				el.size=val;
				break;
			case "f_ml":
				if(val<0) break;
				el.maxLength=val;
				break;
			case "f_checked":
				if(val=="true"){
					var an=editor.getAllAncestors();
					str=HTMLArea.getHTML(an[0],true);
					str=str.substr(0,str.length-1)+ " checked>";
					an[1].removeChild(an[0]);
					editor.insertHTML(str);
				}else{
					var an=editor.getAllAncestors();
					str=HTMLArea.getHTML(an[0],true);
					str=str.replace('checked="checked"', "");
					str=str.replace('checked="true"', "");
					an[1].removeChild(an[0]);
					editor.insertHTML(str);
				}
				break;
			case "f_lt":
				el.href=val;
				break;
			case "f_target":
				el.target=val;
				break;
			case "f_text":
				el.innerHTML=val;
				break;
			case "f_alt":
				el.alt=val;
				break;
			case "f_width":
				el.style.width = ("" + val) + params.f_unit;
				break;
			case "f_unit":break;
			case "f_height":
				el.style.height = ("" + val) + params.f_unit;
				break;
			case "f_borders":
				el.border = val;
				break;
			case "f_align":
				el.align = val;
				break;
			case "f_src":
				el.src=val;
				break;
			case "f_face":
				el.face=val;
				break;
			case "f_char":
				el.ch = val;
				break;
			case "f_valign":
				el.vAlign = val;
				break;
			case "f_ta_value":
				el.value = val;
				el.innerHTML = val;
				break;
			case "f_cols":
				if(val<0) break;
				el.cols = val;
				break;
			case "f_rows":
				if(val<0) break;
				el.rows = val;
				break;
			case "f_type":
				if(val=="hidden"){
					var tmp=HTMLArea.getHTML(el,true);
					var ht;
					ht=/<input(.*?)plshidden=\"hidden\"(.*?)>/gim;
					var htcont;
					try{
						htcont=tmp.match(ht);
					}catch(e){
					}
					if(htcont){
						el.type="text";
					}else{
						//var tmp=htcont[0];
						tmp=tmp.replace('type="hidden"','type="text"');
						tmp=tmp.replace("type='hidden'",'type="text"');
						tmp=tmp.replace('type=hidden','type="text"');
						var tmp1=tmp.substr(0,tmp.length-1);
						tmp=tmp1+' plshidden="hidden">';
						var an=editor.getAllAncestors();
						an[1].removeChild(an[0]);
						editor.insertHTML(tmp);
					}
				}else{
					el.type=val;
					if(val.toLowerCase()=="reset" && (el.value.toLowerCase()=="reset" || el.value.toLowerCase()=="submit" || el.value.toLowerCase()=="button")){
						el.value="reset";
					}else if(val.toLowerCase()=="submit" && (el.value.toLowerCase()=="reset" || el.value.toLowerCase()=="submit" || el.value.toLowerCase()=="button")){
						el.value="submit";
					}else if(val.toLowerCase()=="button" && (el.value.toLowerCase()=="reset" || el.value.toLowerCase()=="submit")){
						el.value="button";
					}
				}
				break;
			}
			if(el.tagName.toLowerCase()=="select"){
				if(/f_ltext/.test(i)){
					Arr[cr]=params[i];
					cr++;
				}
			
				if(/f_lval/.test(i)){
					Arr1[cr1]=params[i];
					cr1++;
				}
			}
		}
		
		if(el.tagName.toLowerCase()=="select"){
			var s1="";
			el.innerHTML=s1;
			for(t=0;t<Arr1.length;t++){
				var opt=document.createElement("option");
				opt.value=Arr1[t];
				opt.text=Arr[t];
				el.appendChild(opt);
				
			}
		}
		
		dialog.editor.forceRedraw();
		dialog.editor.focusEditor();
		dialog.editor.updateToolbar();
		if(el.tagName.toLowerCase()=="table" || el.tagName.toLowerCase()=="tr"  || el.tagName.toLowerCase()=="td"){
			var save_collapse = el.style.borderCollapse;
			el.style.borderCollapse = "collapse";
			el.style.borderCollapse = "separate";
			el.style.borderCollapse = save_collapse;
		}
},
function (dialog) {
			f_caption = "";
			capel = el.getElementsByTagName("caption")[0];
		if (capel) {
			f_caption = capel.innerHTML;
		}
			f_summary = el.summary;
			f_spacing = el.cellSpacing;
			f_padding = el.cellPadding;
			f_frames = el.frame;
			f_rules = el.rules;
			f_name=el.name;
			f_action=el.action;
			f_method=el.method;
			f_title=el.title;
			f_value=el.value;
			
			var tmp=HTMLArea.getHTML(el,true);
			var ht;
			ht=/<input(.*?)plshidden=\"hidden\"(.*?)>/gim;
			var htcont;
			try{
				htcont=tmp.match(ht);
			}catch(e){
			}
			if(htcont){
				f_type="hidden";
			}else{
				f_type=el.type;
			}
			
			f_size=el.size;
			f_ml=el.maxLength;
			f_checked=el.checked;
			f_lt=el.href;
			f_target=el.target;
			f_text=el.text;
			f_alt=el.alt;
			f_width = parseInt(el.style.width);
		isNaN(f_width) && (f_width = "");
			f_height=parseInt(el.style.height);
		isNaN(f_height) && (f_height = "");
			f_borders=el.border;
			f_align=el.align;
			f_src=el.src;
			f_face=el.face;
			f_unit = /%/.test(el.style.width) ? 'percent' : 'pixels';
			f_valign = el.vAlign;
			f_char = el.ch;
			f_cols=el.cols;
			f_rows=el.rows;
			f_ta_value=el.value;
			f_lval1=el.options;
			//f_lval="";
			//f_ltext="";
			

		function selected(val) {
			return val ? " selected" : "";
		};
var sttemp;
if(el.id.toLowerCase()=="asp" || el.id.toLowerCase()=="php" || el.id.toLowerCase()=="script"){
	sttemp=el.id.toLowerCase();
}else{
	sttemp=el.tagName.toLowerCase();
}

dialog.content.style.width = "500px";
s="";
s="\
<div class='title'\
style='background: url(" + fHERE()+"img/tag-prop.gif"+ ") #fff 98% 50% no-repeat'>" + sttemp + fMessage("tagprop1") + "\
</div> \
";
		

switch (el.tagName.toLowerCase()){
	case "body": break;
    case "p":break;
    case "span":break;
    case "tbody":break;
    case "td":
    s=s+" \
    <table style='width:100%'> \
  <tr> \
    <td id='--HA-layout'> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
break;
    case "tr":
    s=s+" \
    <table style='width:100%'> \
  <tr> \
    <td id='--HA-layout'> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
break;
    case "table":
    s=s+" \
    <table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("description") + "</legend> \
       <table style='width:100%'> \
        <tr> \
          <td class='label'>" + fMessage("caption") + ":</td> \
          <td class='value'><input type='text' name='f_caption' value='" + f_caption + "'/></td> \
        </tr><tr> \
          <td class='label'>" + fMessage("summary") + ":</td> \
          <td class='value'><input type='text' name='f_summary' value='" + f_summary + "'/></td> \
        </tr> \
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr><td id='--HA-layout'></td></tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("spacingandpadding") + "</legend> \
       <table style='width:100%'> \
        <tr> \
          <td class='label'>" + fMessage("spacing") + ":</td> \
          <td><input type='text' name='f_spacing' size='5' value='" + f_spacing + "' /> &nbsp;" + fMessage("padding") + ":\
            <input type='text' name='f_padding' size='5' value='" + f_padding + "' /> &nbsp;&nbsp;" + fMessage("pixels") + "\
          </td> \
        </tr> \
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("frameandborders") + "</legend> \
        <table width='100%'> \
          <tr> \
            <td class='label'>" + fMessage("borders") + ":</td> \
            <td><input name='f_borders' type='text' size='5' value='" + f_borders + "' /> &nbsp;&nbsp;" + fMessage("pixels") + "</td> \
          </tr> \
          <tr> \
            <td class='label'>" + fMessage("frames") + ":</td> \
            <td> \
              <select name='f_frames'> \
                <option value='void'" + selected(f_frames == "void") + ">" + fMessage("nosides") + "</option> \
                <option value='above'" + selected(f_frames == "above") + ">" + fMessage("thetopsideonly") + "</option> \
                <option value='below'" + selected(f_frames == "below") + ">" + fMessage("thebottomsideonly") + "</option> \
                <option value='hsides'" + selected(f_frames == "hsides") + ">" + fMessage("thetopandbottomsidesonly") + "</option> \
                <option value='vsides'" + selected(f_frames == "vsides") + ">" + fMessage("therightandleftsidesonly") + "</option> \
                <option value='lhs'" + selected(f_frames == "lhs") + ">" + fMessage("thelefthandsideonly") + "</option> \
                <option value='rhs'" + selected(f_frames == "rhs") + ">" + fMessage("therighthandsideonly") + "</option> \
                <option value='box'" + selected(f_frames == "box") + ">" + fMessage("allfoursides") + "</option> \
              </select> \
            </td> \
          </tr> \
          <tr> \
            <td class='label'>" + fMessage("rules") + ":</td> \
            <td> \
              <select name='f_rules'> \
                <option value='none'" + selected(f_rules == "none") + ">" + fMessage("norules") + "</option> \
                <option value='rows'" + selected(f_rules == "rows") + ">" + fMessage("ruleswillappearbetweenrowsonly") + "</option> \
                <option value='cols'" + selected(f_rules == "cols") + ">" + fMessage("ruleswillappearbetweencolumnsonly") + "</option> \
                <option value='all'" + selected(f_rules == "all") + ">" + fMessage("ruleswillappearbetweenallrowsandcolumns") + "</option> \
              </select> \
            </td> \
          </tr> \
        </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
   
    break;
    case "img":
    if(el.id.toLowerCase()=="asp" || el.id.toLowerCase()=="php" || el.id.toLowerCase()=="script") break;
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("description") + "</legend> \
       <table style='width:100%'> \
        <tr> \
          <td class='label'>" + fMessage("title") + ":</td> \
          <td class='value'><input type='text' name='f_title' value='" + f_title+ "'/></td> \
        </tr><tr> \
          <td class='label'>" + fMessage("alt") + ":</td> \
          <td class='value'><input type='text' name='f_alt' value='" + f_alt + "'/></td> \
        </tr> \
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr><td id='--HA-layout'></td></tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("layout") + "</legend> \
       <table style='width:100%'> \
        <tr> \
           <td class='label'>" + fMessage("width") + ":</td> \
           <td><input type='text' name='f_width' value='" + f_width + "' size='5' /> \
             <select name='f_unit'> \
             <option value=''" + selected(f_unit == "") + ">" + "" + "</option> \
               <option value='%'" + selected(f_unit == "percent") + ">" + fMessage("percent") + "</option> \
               <option value='px'" + selected(f_unit.toLowerCase() == "pixels") + ">" + fMessage("pixels") + "</option> \
             </select> \
             </td> \
			 <td class='label'>" + fMessage("align") + ":</td> \
            <select name='f_align'> \
            <option value=''" + selected(f_align == "") + ">" + "" + "</option> \
               <option value='left'" + selected(f_align.toLowerCase() == "left") + ">" + fMessage("left") + "</option> \
               <option value='right'" + selected(f_align.toLowerCase() == "right") + ">" + fMessage("right") + "</option> \
             </select> \
           </td> \
             <tr>\
           <td class='label'>" + fMessage("height") + ":</td> \
			<td><input type='text' name='f_height' value='" + f_height + "' size='5' /> \
             <select name='f_unit'> \
             <option value=''" + selected(f_unit == "") + ">" + "" + "</option> \
               <option value='%'" + selected(f_unit == "percent") + ">" + fMessage("percent") + "</option> \
               <option value='px'" + selected(f_unit.toLowerCase() == "pixels") + ">" + fMessage("pixels") + "</option> \
             </select>\
             </td> \
          <td class='label'>" + fMessage("border") + ":</td> \
           <td><input name='f_borders' type='text' size='5' value='" + f_borders + "' /> &nbsp;&nbsp;" + fMessage("pixels") + "</td> \
         </tr> \
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("source") + "</legend> \
        <table width='100%'> \
          <tr> \
            <td class='label'>" + fMessage("src") + ":</td> \
     <td><input type='text' name='f_src' value='" + f_src + "' size='40' /> \
          </tr> \
        </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";break;
    case "form":
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("propertieselement") + "</legend> \
       <table style='width:100%'> \
        <tr> \
          <td class='label'>" + fMessage("name") + ":</td> \
          <td class='value'><input type='text' name='f_name' value='" + f_name+ "'/></td> \
          <td class='label'>" + fMessage("action") + ":</td> \
          <td class='value'><input type='text' name='f_action' value='" + f_action + "'/></td> \
         </tr><tr> \
         <td class='label'>" + fMessage("method") + ":</td> \
         <td>\
         <select name='f_method'> \
         <option value=''" + selected(f_method == "") + ">" + "" + "</option> \
               <option value='get'" + selected(f_method.toLowerCase() == "get") + ">" + fMessage("get") + "</option> \
               <option value='post'" + selected(f_method.toLowerCase() == "post") + ">" + fMessage("post") + "</option> \
             </select> \
          </td>\
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
"; break;
    case "input":
		if(el.type.toLowerCase()=="checkbox" || el.type.toLowerCase()=="radio"){
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" +el.type.toLowerCase()+  fMessage("pe") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("name") + ":</td> \
          <td class='value'><input type='text' name='f_name' value='" + f_name + "'/></td> \
          <td class='label'>" + fMessage("value") + ":</td> \
          <td class='value'><input type='text' name='f_value' value='" + f_value + "'/></td> \
          </tr>\
          <tr> \
          <td class='label'>" + fMessage("checked") + ":</td> \
          <td class='value'><select name='f_checked'> \
               <option value=false" + selected(f_checked == "") + ">" + fMessage("unchecked") + "</option> \
               <option value=true" + selected(f_checked == true) + ">" + fMessage("checked") + "</option> \
             </select> </td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
"; 
		}else if(el.type.toLowerCase()=="button" || el.type.toLowerCase()=="submit" || el.type.toLowerCase()=="reset") {
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>"  +el.type.toLowerCase()+ fMessage("pe") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("name") + ":</td> \
          <td class='value'><input type='text' name='f_name' value='" + f_name+ "'/></td> \
          <td class='label'>" + fMessage("value") + ":</td> \
          <td class='value'><input type='text' name='f_value' value='" + f_value + "'/></td> \
          <td class='label'>" + fMessage("type") + ":</td> \
          <td class='value'><select name='f_type'> \
               <option value='button'" + selected(f_type.toLowerCase() == "button") + ">" + fMessage("button") + "</option> \
               <option value='submit'" + selected(f_type.toLowerCase() == "submit") + ">" + fMessage("submit") + "</option> \
               <option value='reset'" + selected(f_type.toLowerCase() == "reset") + ">" + fMessage("reset") + "</option> \
             </select> </td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
		}else if(el.type.toLowerCase()=="text" || el.type.toLowerCase()=="password" || el.type.toLowerCase()=="hidden") {
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>"  +el.type.toLowerCase()+fMessage("pe") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("name") + ":</td> \
          <td class='value'><input type='text' name='f_name' value='" + f_name+ "'/></td> \
          <td class='label'>" + fMessage("value") + ":</td> \
          <td class='value'><input type='text' name='f_value' value='" + f_value + "'/></td> \
          <td class='label'>" + fMessage("type") + ":</td> \
          <td class='value'><select name='f_type'> \
               <option value='text'" + selected(f_type.toLowerCase() == "text") + ">" + fMessage("text") + "</option> \
               <option value='password'" + selected(f_type.toLowerCase() == "password") + ">" + fMessage("password") + "</option> \
               <option value='hidden'" + selected(f_type.toLowerCase() == "hidden") + ">" + fMessage("hidden") + "</option> \
             </select> </td> \
         </tr>\
         <tr>\
         <td class='label'>" + fMessage("size") + ":</td> \
          <td class='value'><input type='text' name='f_size' value='" + f_size+ "'/></td> \
          <td colspan=3 class='label'>" + fMessage("maximallenght") + ":</td> \
          <td class='value'><input type='text' name='f_ml' value='" + f_ml + "'/></td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
		}
		break;
	case "ol":
	s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>"  +el.tagName.toLowerCase()+fMessage("pe") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("type") + ":</td> \
          <td class='value'><select name='f_type'> \
               <option value='1'" + selected(f_type.toLowerCase() == "1") + ">" + fMessage("numbers") + "</option> \
               <option value='a'" + selected(f_type.toLowerCase() == "a") + ">" + fMessage("lowercaseletters") + "</option> \
               <option value='A'" + selected(f_type.toLowerCase() == "A") + ">" + fMessage("uppercaseletters") + "</option> \
               <option value='i'" + selected(f_type.toLowerCase() == "i") + ">" + fMessage("smallromannumerals") + "</option> \
               <option value='I'" + selected(f_type.toLowerCase() == "I") + ">" + fMessage("largeromannumerals") + "</option> \
             </select> </td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
	break;
	case "ul":
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>"  +el.tagName.toLowerCase()+fMessage("pe") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("type") + ":</td> \
          <td class='value'><select name='f_type'> \
               <option value='disc'" + selected(f_type.toLowerCase() == "disc") + ">" + fMessage("disc") + "</option> \
               <option value='circle'" + selected(f_type.toLowerCase() == "circle") + ">" + fMessage("circle") + "</option> \
               <option value='square'" + selected(f_type.toLowerCase() == "square") + ">" + fMessage("square") + "</option> \
             </select> </td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
	break;
    case "textarea": 
     s=s+" \
<table style='width:100%'> \
 <tr> \
    <td> \
      <fieldset><legend>" + fMessage("name") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("name") + ":</td><td class='value'><input type='text' name='f_name' value='" + f_name+ "'/></td>\
         </tr>\
         <tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("textareaelementvalue") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td><textarea name='f_ta_value' style='height: 100%; width: 100%'>"+f_ta_value+"</textarea></td> \
          </td> \
         </tr>\
         <tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("layout") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("columns") + ":</td><td class='value'><input type='text' name='f_cols' value='" + f_cols+ "'/></td><td class='label'>" + fMessage("rows") + ":</td><td class='value'><input type='text' name='f_rows' value='" + f_rows+ "'/></td> \
          </td> \
         </tr>\
         <tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
    break;
    case "select":
    var q='"';
    var q1="\'";
    var q2=escape("<input type=text id=new onclick='javascript:document.getElementById(\"hidden\").value=this.id'>");
   var q3=escape("<input type=text id=new1 onclick='javascript:document.getElementById(\"hidden\").value=this.id'>");
    s=s+" \
    <input type='hidden' name='hidden' id='hidden' value='0'>\
    <input type='hidden' name='hidden1' id='hidden1' value='"+f_lval1.length+"'>\
    <input type='hidden' name='hidden2' id='hidden2' value='javascript:document.getElementById("+q+"hidden"+q+").value=this.id;'>\
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("selectproperieselement") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("name") + ":</td><td class='value'><input type='text' name='f_name' value='" + f_name+ "'/> <td class='label'>" + fMessage("size") + ":</td><td class='value'><input type='text' name='f_size' value='" + f_size+ "'/></td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("listvalues") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td align=center><input type=button onclick='javascript: var h=document.getElementById("+q+"hidden"+q+").value; var h1=document.getElementById("+q+"hidden1"+q+").value; var tr=document.getElementById("+q+"tr"+q+"+h);if(!tr){alert("+q+fMessage("pleaseclick")+q+")}else{var otr = tr.cloneNode(true);var c=h1++; var first=otr.getElementsByTagName("+q+"td"+q+").item(0).firstChild;first.id=c;first.value="+q+""+q+"; first.name="+q+"f_lval"+q+"+c; var first1=otr.getElementsByTagName("+q+"td"+q+").item(1).firstChild;first1.id=c;first1.value="+q+""+q+"; first1.name="+q+"f_ltext"+q+"+c;otr.id="+q+"tr"+q+"+c;  tr.parentNode.insertBefore(otr, tr.nextSibling);document.getElementById("+q+"hidden1"+q+").value=h1+1;} ' value=" + fMessage("add") + "></td>\
        <td align=center><input type=button onclick='javascript: var h=document.getElementById("+q+"hidden"+q+").value; var tr=document.getElementById("+q+"tr"+q+"+h);if(!tr){alert("+q+fMessage("pleaseclick")+q+")}else{ var par = tr.parentNode;if (par.rows.length == 3) { alert("+q+fMessage("notallowedoperation")+q+") }else{par.removeChild(tr);}}' value=" + fMessage("del") + "> \
          </td> \
          </tr>\
          <tr>\
        <td align=center>" + fMessage("listvalue") + "</td><td align=center>" + fMessage("listtext") + "</td> \
       </tr>\
       <td colspan=2>\
          <div style='width:470px; height:200px; overflow: scroll;'>\
          <table style='width:100%'> \
          <tr> \
       ";
       
      if(f_lval1.length==0){
      s=s + " \ <tr id=tr0> \
        <td class='value'><input type='text' id=0 name='f_lval0' onclick='javascript:document.getElementById("+q+"hidden"+q+").value=this.id;' value=''/></td><td class='value'><input type='text' id=0 name='f_ltext0' onclick='javascript:document.getElementById("+q+"hidden"+q+").value=this.id;' value=''/> \
         </td> \
         </tr>\
         ";
      }else{
       for(var y=0; y<f_lval1.length; y++){
       s=s + " \ <tr id=tr"+y+"> \
        <td class='value'><input type='text' id="+y+" name='f_lval"+y+"' onclick='javascript:document.getElementById("+q+"hidden"+q+").value=this.id;' value='" + f_lval1.item(y).value+ "'/></td><td class='value'><input type='text'id="+y+" name='f_ltext"+y+"' onclick='javascript:document.getElementById("+q+"hidden"+q+").value=this.id;' value='" + f_lval1.item(y).text+ "'/> \
         </td> \
         </tr>\
         ";
       }
      } 
      s=s + "</td></tr></div></fieldset></td></tr><tr><td id='--HA-style'></td></tr></table>";
    break;
    case "a":
    s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("propertieselement") + "</legend> \
       <table style='width:100%'> \
        <tr> \
        <td class='label'>" + fMessage("linkto") + ":</td> \
          <td class='value'><input type='text' name='f_lt' value='" + f_lt+ "'/></td> \
          <td class='label'>" + fMessage("target") + ":</td> \
          <td class='value'><select name='f_target'> \
          <option value=''" + selected(f_target.toLowerCase() == "") + ">" + "" + "</option> \
               <option value='_self'" + selected(f_target.toLowerCase() == "_self") + ">" + fMessage("samewindow") + "</option> \
               <option value='_new'" + selected(f_target.toLowerCase() == "_new") + ">" + fMessage("newwindow") + "</option> \
               <option value='_blank'" + selected(f_target.toLowerCase() == "_blank") + ">" + fMessage("blankwindow") + "</option> \
               <option value='_parent'" + selected(f_target.toLowerCase() == "_parent") + ">" + fMessage("parentwindow") + "</option> \
               <option value='_top'" + selected(f_target.toLowerCase() == "_top") + ">" + fMessage("topmostwindow") + "</option> \
             </select> </td> \
         </tr>\
         <tr>\
         <td class='label'>" + fMessage("text") + ":</td> \
          <td class='value'><input type='text' name='f_text' value='" + f_text+ "'/></td> \
          <td class='label'>" + fMessage("title") + ":</td> \
          <td class='value'><input type='text' name='f_title' value='" + f_title + "'/></td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";
break;
    case "font":
		s=s+" \
<table style='width:100%'> \
  <tr> \
    <td> \
      <fieldset><legend>" + fMessage("propertieselement") + "</legend> \
       <table style='width:100%'> \
        <tr> \
          <td class='label'>" + fMessage("face") + ":</td> \
          <td class='value'><select name='f_face'> \
          <option value=''" + selected(f_face == "") + ">" + "" + "</option> \
               <option value='Arial'" + selected(f_face.toLowerCase() == "arial") + ">" + "Arial" + "</option> \
               <option value='Verdana'" + selected(f_face.toLowerCase() == "verdana") + ">" + "Verdana" + "</option> \
               <option value='Times'" + selected(f_face.toLowerCase() == "times") + ">" + "Times" + "</option> \
               <option value='Courier'" + selected(f_face.toLowerCase() == "courier") + ">" + "Courier" + "</option> \
               <option value='Tahoma'" + selected(f_face.toLowerCase() == "tahoma") + ">" + "Tahoma" + "</option> \
               <option value='Geneva'" + selected(f_face.toLowerCase() == "geneva") + ">" + "Geneva" + "</option> \
               <option value='Helvetica'" + selected(f_face.toLowerCase() == "helvetica") + ">" + "Helvetica" + "</option> \
               <option value='Georgia'" + selected(f_face.toLowerCase() == "georgia") + ">" + "Georgia" + "</option> \
             </select> </td> \
             <td class='label'>" + fMessage("size") + ":</td> \
          <td class='value'><select name='f_size'> \
               <option value=''" + selected(f_size == "") + ">" + "" + "</option> \
               <option value='1'" + selected(f_size == "1") + ">" + "1" + "</option> \
               <option value='2'" + selected(f_size == "2") + ">" + "2" + "</option> \
               <option value='3'" + selected(f_size == "3") + ">" + "3" + "</option> \
               <option value='4'" + selected(f_size == "4") + ">" + "4" + "</option> \
               <option value='5'" + selected(f_size == "5") + ">" + "5" + "</option> \
               <option value='6'" + selected(f_size == "6") + ">" + "6" + "</option> \
               <option value='7'" + selected(f_size == "7") + ">" + "7" + "</option> \
             </select> </td> \
         </tr>\
       </table> \
      </fieldset> \
    </td> \
  </tr> \
  <tr> \
    <td id='--HA-style'></td> \
  </tr> \
</table> \
";break;
default: break;
}

dialog.content.innerHTML = s;
if(el.tagName.toLowerCase()=="table" || el.tagName.toLowerCase()=="td" || el.tagName.toLowerCase()=="tr"){
var p = dialog.doc.getElementById("--HA-layout");
		var st_layout = editor.createStyleLayoutFieldset(dialog.doc, dialog.editor, el);
		p.appendChild(st_layout); 
}
dialog.modal = true;
		dialog.addButtons("ok", "cancel");
		dialog.showAtElement(dialog.editor._iframe, "c");
	});
};


HTMLArea.prototype.TagEdit = function() {
var an=editor.getAllAncestors();
var ell=an.length;
var el;

if(ell<2){
	alert(fMessage("tagisnotselected"));
}else{
	el=an[0];

	if(an[0].tagName.toLowerCase()=="tbody" || an[0].tagName.toLowerCase()=="tr" ){
		html=an[1].innerHTML;
	}else{
		html=HTMLArea.getHTML(an[0],true);	
	}
	try{
		html=fRemoveVT(html);
	}catch(e){
		html=html;
	}
	if(html){
		var obj=new Object;
		obj.lang=Lang;//editor.lang;
		obj.html=html;	
		this._popupDialog("edit_tag.html", function(tag) {
			try{
				tag=fAddVT(tag);
			}catch(e){
				tag=tag;
			}
			if(an[0].tagName.toLowerCase()=="td"){
				editor.selectNodeContents(an[0]);
				editor.insertHTML(tag);
			}else if(an[0].tagName.toLowerCase()=="tbody" || an[0].tagName.toLowerCase()=="tr" ){
				an[1].innerHTML=tag;
			}else{
				an[1].removeChild(an[0]);
				editor.insertHTML(tag);
			}
		}, obj);
	}else{
		alert(fMessage("tagisnotselected"));
	}
}	
};

HTMLArea.prototype._popupDialog = function(url, action, init) {
	Dialog(this.popupURL(url), action, init);
};

// paths

HTMLArea.prototype.imgURL = function(file, plugin) {
	if (typeof plugin == "undefined") {
		return this.config.editorURL + file;
	} else {
		return this.config.editorURL + "plugins/" + plugin + "/img/" + file;
	}
};

HTMLArea.prototype.popupURL = function(file) {
	return this.config.editorURL + this.config.popupURL + file;
};

var mvInsertedId=0;
HTMLArea.prototype.fInsertHtmlObject = function(HTML) {

  
    this.insertHTML(HTML);
    return 0;
};


HTMLArea.prototype.sInsertForm = function() {
    this.fInsertHtmlObject('<form id="form'+mvInsertedId+'" name="" action="" method="post">&nbsp;&nbsp;</form>');
    mvInsertedId=mvInsertedId+1;
};


HTMLArea.prototype.sFormTextField= function() {
  
    this.fInsertHtmlObject('<input type="text" id="text'+mvInsertedId+'" name="" value="">&nbsp;');
   mvInsertedId=mvInsertedId+1;
};
HTMLArea.prototype.sFormTextArea= function() {
    this.fInsertHtmlObject('<textarea id="textarea'+mvInsertedId+'" name="" >&nbsp;</textarea>&nbsp;');
    mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sFormButton= function() {
    this.fInsertHtmlObject('<input type="button" id="button'+mvInsertedId+'" name="" value="button">&nbsp;');
    mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sFormSubmit= function() {
    this.fInsertHtmlObject('<input type="submit" id="button'+mvInsertedId+'" name="" value="submit">&nbsp;');
    mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sFormCheck= function() {
    this.fInsertHtmlObject('<input type="checkbox" id="check'+mvInsertedId+'" name="">&nbsp;');
    mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sFormRadio= function() {
    this.fInsertHtmlObject('<input type="radio" id="radio'+mvInsertedId+'" name="">&nbsp;');
    mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sFormDropdown= function() {
    this.fInsertHtmlObject('<select id="select'+mvInsertedId+'" name=""><option value=""></option></select>&nbsp;');
    mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sFormHidden= function() {
    this.fInsertHtmlObject('<input type="text" plshidden="hidden" id="hidden'+mvInsertedId+'" name="" >&nbsp;');
   mvInsertedId=mvInsertedId+1;
};

HTMLArea.prototype.sSelectAll= function() {

editor.selectNodeContents(this._doc.body);
};

HTMLArea.prototype.createStyleLayoutFieldset = function(doc, editor, el) {

	var fieldset = doc.createElement("fieldset");
	var legend = doc.createElement("legend");
	fieldset.appendChild(legend);
	legend.innerHTML = fMessage("layout");
	var table = doc.createElement("table");
	fieldset.appendChild(table);
	table.style.width = "100%";
	var tbody = doc.createElement("tbody");
	table.appendChild(tbody);

	var tagname = el.tagName.toLowerCase();
	var tr, td, input, select, option, options, i;

	if (tagname != "td" && tagname != "tr" && tagname != "th") {
		tr = doc.createElement("tr");
		tbody.appendChild(tr);
		td = doc.createElement("td");
		td.className = "label";
		tr.appendChild(td);
		td.innerHTML = fMessage("float") + ":";
		td = doc.createElement("td");
		tr.appendChild(td);
		select = doc.createElement("select");
		td.appendChild(select);
		select.name = "f_st_float";
		options = [fMessage("none"), fMessage("left"), fMessage("right")];
		for (i in options) {
			var Val = options[i];
			var val = options[i].toLowerCase();
			option = doc.createElement("option");
			option.innerHTML = Val;
			option.value = val;
			option.selected = (("" + el.style.cssFloat).toLowerCase() == val);
			select.appendChild(option);
		}
	}

	tr = doc.createElement("tr");
	tbody.appendChild(tr);
	td = doc.createElement("td");
	td.className = "label";
	tr.appendChild(td);
	td.innerHTML = fMessage("width") + ":";
	td = doc.createElement("td");
	tr.appendChild(td);
	input = doc.createElement("input");
	input.type = "text";
	input.value = TableOperations.getLength(el.style.width);
	input.size = "5";
	input.name = "f_st_width";
	input.style.marginRight = "0.5em";
	td.appendChild(input);
	select = doc.createElement("select");
	select.name = "f_st_widthUnit";
	option = doc.createElement("option");
	option.innerHTML = fMessage("percent");
	option.value = "%";
	option.selected = /%/.test(el.style.width);
	select.appendChild(option);
	option = doc.createElement("option");
	option.innerHTML = fMessage("pixels");
	option.value = "px";
	option.selected = /px/.test(el.style.width);
	select.appendChild(option);
	td.appendChild(select);

	select.style.marginRight = "0.5em";
	td.appendChild(doc.createTextNode(fMessage("textalign") + ":"));
	select = doc.createElement("select");
	select.style.marginLeft = select.style.marginRight = "0.5em";
	td.appendChild(select);
	select.name = "f_st_textAlign";
	options = [fMessage("left"), fMessage("center"), fMessage("right"), fMessage("justify")];
	if (tagname == "td") {
		options.push(fMessage("char"));
	}
	input = doc.createElement("input");
	input.name = "f_st_textAlignChar";
	input.size = "1";
	input.style.fontFamily = "monospace";
	td.appendChild(input);
	for (i in options) {
		var Val = options[i];
		var val = Val.toLowerCase();
		option = doc.createElement("option");
		option.value = val;
		option.innerHTML = Val;
		option.selected = (el.style.textAlign.toLowerCase() == val);
		select.appendChild(option);
	}
	function setCharVisibility(value) {
		input.style.visibility = value ? "visible" : "hidden";
		if (value) {
			input.focus();
			input.select();
		}
	};
	select.onchange = function() { setCharVisibility(this.value == "char"); };
	setCharVisibility(select.value == "char");

	tr = doc.createElement("tr");
	tbody.appendChild(tr);
	td = doc.createElement("td");
	td.className = "label";
	tr.appendChild(td);
	td.innerHTML = fMessage("height") + ":";
	td = doc.createElement("td");
	tr.appendChild(td);
	input = doc.createElement("input");
	input.type = "text";
	input.value = TableOperations.getLength(el.style.height);
	input.size = "5";
	input.name = "f_st_height";
	input.style.marginRight = "0.5em";
	td.appendChild(input);
	select = doc.createElement("select");
	select.name = "f_st_heightUnit";
	option = doc.createElement("option");
	option.innerHTML = fMessage("percent");
	option.value = "%";
	option.selected = /%/.test(el.style.height);
	select.appendChild(option);
	option = doc.createElement("option");
	option.innerHTML = fMessage("pixels");
	option.value = "px";
	option.selected = /px/.test(el.style.height);
	select.appendChild(option);
	td.appendChild(select);

	select.style.marginRight = "0.5em";
	td.appendChild(doc.createTextNode(fMessage("verticalalign") + ":"));
	select = doc.createElement("select");
	select.name = "f_st_verticalAlign";
	select.style.marginLeft = "0.5em";
	td.appendChild(select);
	options = [fMessage("top"), fMessage("middle"), fMessage("bottom"), fMessage("baseline")];
	for (i in options) {
		var Val = options[i];
		var val = Val.toLowerCase();
		option = doc.createElement("option");
		option.value = val;
		option.innerHTML = Val;
		option.selected = (el.style.verticalAlign.toLowerCase() == val);
		select.appendChild(option);
	}

	return fieldset;
};

HTMLArea.prototype.TagStl = function(params, element) {
var ancestors = editor.getAllAncestors();
var el=ancestors[0];
var s="";

var dialog = new PopupWin(editor, fMessage("advancedtagproperties"), function(dialog, params) {
	editor.processStyle(params, el);
	},
	function (dialog) {
	var sttemp;
if(el.id.toLowerCase()=="asp" || el.id.toLowerCase()=="php" || el.id.toLowerCase()=="script"){
	sttemp=el.id.toLowerCase();
}else{
	sttemp=el.tagName.toLowerCase();
}
	s="\
<div class='title'\
style='background: url(" + fHERE()+ "img/tag-stl.gif" + ") #fff 98% 50% no-repeat'>" + sttemp+ Lang["tagprop1"] + "\
</div> \
<table style='width:100%'> \
  <tr> \
  <td id='--HA-style'></td> \
  </tr> \
</table> \
";
dialog.content.style.width = "400px";
dialog.content.innerHTML = s;
var st_prop = editor.createStyleFieldset(dialog.doc, dialog.editor, el);
if(el.id.toLowerCase()=="asp" || el.id.toLowerCase()=="php" || el.id.toLowerCase()=="script"){

}else{
		var p = dialog.doc.getElementById("--HA-style");
		p.appendChild(st_prop);
}
		dialog.modal = true;
		dialog.addButtons("ok", "cancel");
		dialog.showAtElement(dialog.editor._iframe, "c");
		});
	
};

HTMLArea.prototype.createStyleFieldset = function(doc, editor, el) {
	//var i18n = TableOperations.I18N;
	var fieldset = doc.createElement("fieldset");
	var legend = doc.createElement("legend");
	fieldset.appendChild(legend);
	legend.innerHTML = fMessage("cssstyle");
	var table = doc.createElement("table");
	fieldset.appendChild(table);
	table.style.width = "100%";
	var tbody = doc.createElement("tbody");
	table.appendChild(tbody);

	var tr, td, input, select, option, options, i;

	tr = doc.createElement("tr");
	tbody.appendChild(tr);
	td = doc.createElement("td");
	tr.appendChild(td);
	td.className = "label";
	td.innerHTML = fMessage("background") + ":";
	td = doc.createElement("td");
	tr.appendChild(td);
	var df = TableOperations.createColorButton(doc, editor, el.style.backgroundColor, "backgroundColor");
	df.firstChild.nextSibling.style.marginRight = "0.5em";
	td.appendChild(df);
	td.appendChild(doc.createTextNode(fMessage("imageurl") + ": "));
	input = doc.createElement("input");
	input.type = "text";
	input.name = "f_st_backgroundImage";
	if (el.style.backgroundImage.match(/url\(\s*(.*?)\s*\)/)) {
		input.value = RegExp.$1;
	}
	// input.style.width = "100%";
	td.appendChild(input);

	tr = doc.createElement("tr");
	tbody.appendChild(tr);
	td = doc.createElement("td");
	tr.appendChild(td);
	td.className = "label";
	td.innerHTML = fMessage("fgcolor") + ":";
	td = doc.createElement("td");
	tr.appendChild(td);
	td.appendChild(TableOperations.createColorButton(doc, editor, el.style.color, "color"));

	// for better alignment we include an invisible field.
	input = doc.createElement("input");
	input.style.visibility = "hidden";
	input.type = "text";
	td.appendChild(input);

	tr = doc.createElement("tr");
	tbody.appendChild(tr);
	td = doc.createElement("td");
	tr.appendChild(td);
	td.className = "label";
	td.innerHTML = fMessage("border") + ":";
	td = doc.createElement("td");
	tr.appendChild(td);

	var colorButton = TableOperations.createColorButton(doc, editor, el.style.borderColor, "borderColor");
	var btn = colorButton.firstChild.nextSibling;
	td.appendChild(colorButton);
	// borderFields.push(btn);
	btn.style.marginRight = "0.5em";

	select = doc.createElement("select");
	var borderFields = [];
	td.appendChild(select);
	select.name = "f_st_borderStyle";
	options = [fMessage("none"), fMessage("dotted"), fMessage("dashed"), fMessage("solid"), fMessage("double"), fMessage("groove"), fMessage("ridge"), fMessage("inset"), fMessage("outset")];
	var currentBorderStyle = el.style.borderStyle;
	// Gecko reports "solid solid solid solid" for "border-style: solid".
	// That is, "top right bottom left" -- we only consider the first
	// value.
	(currentBorderStyle.match(/([^\s]*)\s/)) && (currentBorderStyle = RegExp.$1);
	for (i in options) {
		var val = options[i];
		option = doc.createElement("option");
		option.value = val;
		option.innerHTML = val;
		(val == currentBorderStyle) && (option.selected = true);
		select.appendChild(option);
	}
	select.style.marginRight = "0.5em";
	function setBorderFieldsStatus(value) {
		for (i in borderFields) {
			var el = borderFields[i];
			el.style.visibility = value ? "hidden" : "visible";
			if (!value && (el.tagName.toLowerCase() == "input")) {
				el.focus();
				el.select();
			}
		}
	};
	select.onchange = function() { setBorderFieldsStatus(this.value == "none"); };

	input = doc.createElement("input");
	borderFields.push(input);
	input.type = "text";
	input.name = "f_st_borderWidth";
	input.value = TableOperations.getLength(el.style.borderWidth);
	input.size = "5";
	td.appendChild(input);
	input.style.marginRight = "0.5em";
	var span = doc.createElement("span");
	span.innerHTML = fMessage("pixels");
	td.appendChild(span);
	borderFields.push(span);

	setBorderFieldsStatus(select.value == "none");

	if (el.tagName.toLowerCase() == "table") {
		// the border-collapse style is only for tables
		tr = doc.createElement("tr");
		tbody.appendChild(tr);
		td = doc.createElement("td");
		td.className = "label";
		tr.appendChild(td);
		input = doc.createElement("input");
		input.type = "checkbox";
		input.name = "f_st_borderCollapse";
		input.id = "f_st_borderCollapse";
		var val = (/collapse/i.test(el.style.borderCollapse));
		input.checked = val ? 1 : 0;
		td.appendChild(input);

		td = doc.createElement("td");
		tr.appendChild(td);
		var label = doc.createElement("label");
		label.htmlFor = "f_st_borderCollapse";
		label.innerHTML = fMessage("collapsedborders");
		td.appendChild(label);
	}

	return fieldset;
};



HTMLArea.prototype.processStyle = function(params, element) {
	var style = element.style;
	for (var i in params) {
		var val = params[i];
		switch (i) {
		    case "f_st_backgroundColor":
				style.backgroundColor = val;
				break;
		    case "f_st_color":
				style.color = val;
				break;
		    case "f_st_backgroundImage":
				if (/\S/.test(val)) {
					style.backgroundImage = "url(" + val + ")";
				} else {
					style.backgroundImage = "none";
				}
				break;
		    case "f_st_borderWidth":
				style.borderWidth = val;
				break;
		    case "f_st_borderStyle":
				style.borderStyle = val;
				break;
		    case "f_st_borderColor":
				style.borderColor = val;
				break;
		    case "f_st_borderCollapse":
				style.borderCollapse = val ? "collapse" : "";
				break;
		    case "f_st_width":
				if (/\S/.test(val)) {
					style.width = val + params["f_st_widthUnit"];
				} else {
					style.width = "";
				}
				break;
		    case "f_st_height":
				if (/\S/.test(val)) {
					style.height = val + params["f_st_heightUnit"];
				} else {
					style.height = "";
				}
				break;
		    case "f_st_textAlign":
				if (val == "char") {
					var ch = params["f_st_textAlignChar"];
					if (ch == '"') {
						ch = '\\"';
					}
					style.textAlign = '"' + ch + '"';
				} else {
					style.textAlign = val;
				}
				break;
		    case "f_st_verticalAlign":
				style.verticalAlign = val;
				break;
		    case "f_st_float":
				style.cssFloat = val;
				break;
			}
	}
};


HTMLArea.prototype.processStyleTab = function(params, element) {
	var style = element.style;
	for (var i in params) {
		var val = params[i];

		switch (i) {
		    case "f_st_borderCollapse":
			style.borderCollapse = val ? "collapse" : "";
			break;
		    case "f_st_width":
			if (/\S/.test(val)) {
				style.width = val + params["f_st_widthUnit"];
			} else {
				style.width = "";
			}
			break;
		    case "f_st_height":
			if (/\S/.test(val)) {
				style.height = val + params["f_st_heightUnit"];
			} else {
				style.height = "";
			}
			break;
		    case "f_st_textAlign":
			if (val == "char") {
				var ch = params["f_st_textAlignChar"];
				if (ch == '"') {
					ch = '\\"';
				}
				style.textAlign = '"' + ch + '"';
			} else {
				style.textAlign = val;
			}
			break;
		    case "f_st_verticalAlign":
			style.verticalAlign = val;
			break;
		}
	}
};

function oWord(pos, wrd, node){
    this.id = pos;
    this.word = wrd;
    this.node = node;
    this.stat = '';
}

var arrWord=new Array; 

HTMLArea.prototype.fSpell = function() {
var myObject = new Object();
idd=0;
HTMLArea.getHTML(doc.body,false);
var sel = this._getSelection();

var range = this._createRange();
myObject.seln=sel;
myObject.lang=Lang;
myObject.range=range;
myObject.doc=doc;
myObject.data=arrData;
myObject.ell=arrElement;
var k=0;
for(var i=0;i<arrData.length;i++){
	var txt=arrData[i].data;
	var re=/[A-Za-z']/;
	var s="",id=-1,str="";
	for(j=0;j<txt.length;j++){
	str=txt.substr(j,1,1);
	var tmp=str.match(re);
		if(tmp){
			if(id<0) {
				id=tmp.index;
			}
			s=s+str;
			if(j==txt.length-1){
				if(s != ""){
					arrWord[k]=new oWord(id,s,arrData[i]);
					k++;
				}
				s="";
				id=-1;
				str="";
			}
		}else{
			if(s != ""){
				arrWord[k]=new oWord(id,s,arrData[i]);
				k++;
			}
			s="";
			id=-1;
			str="";
		}
	}

}
myObject.arr=arrWord;
this._popupDialog("spell.html", function(symbol) {
			if (symbol) { // selection not canceled
				null;//editor.insertHTML(symbol);
			}
		}, myObject);
};

HTMLArea.prototype.fFinde = function() {
var myObject = new Object();

var e,r,t,y,e1,r1;



idd=0;
HTMLArea.getHTML(doc.body,false);
var sel = this._getSelection();
var range1 = this._createRange(sel);
var range = this._createRange();
myObject.lang=Lang;
myObject.seln=sel;
myObject.range=range;
myObject.doc=doc;
myObject.SEL=escape(range1);
myObject.data=arrData;
myObject.ell=arrElement;

this._popupDialog("find.html", function(symbol) {
			if (symbol) { // selection not canceled
				null;//editor.insertHTML(symbol);
			}
		}, myObject);

};


var hal,hat,haw,hah,y1,y2,y3,x1,x2,x3,mvScrX,mvScrY,mvTop,mvLeft,mvHight,mvWidth,mvATop,mvALeft,mvAWidth,mvAHeight,mvOHeight,mvOWidth,mvIHeight,mvIWidth;
HTMLArea.prototype.fFullscreen = function() {
if(editor.fullscreen==true){
	editor.fullscreen=false;
}else{
	editor.fullscreen=true;
}

if(editor.fullscreen==true){
	mvTop=window.screen.top;
	mvLeft = window.screen.left;
	mvATop=window.screen.availTop;
	mvALeft=window.screen.availLeft;
	mvHight = window.screen.height;
	mvWidth = window.screen.width;
	mvAWidth=window.screen.availWidth;
	mvAHeight=window.screen.availHeight;
	mvOHeight=window.outerHeight;
	mvOWidth=window.outerWidth;
	mvIHeight=window.innerHeight;
	mvIWidth=window.innerWidth;
	mvScrX=window.screenX;
	mvScrY=window.screenY;
	
	var setY = window.screen.height - window.screen.availTop;
	var setX = window.screen.width - window.screen.availLeft;
	x1=editor._iframe.style.height;
	y1=editor._iframe.style.width;
	try{
		x2=iframep.style.height;
		y2=iframep.style.width;
	}catch(e){
	
	}
	x3=editor._textArea.style.height;
	
	hah=editor._htmlArea.style.height;
	haw=editor._htmlArea.style.width;
	hat=editor._htmlArea.style.top;
	hal=editor._htmlArea.style.left;
	window.moveTo(setX, setY);
	window.resizeTo(window.screen.availWidth, window.screen.availHeight);
	window.moveTo(setX, setY);
	
	
	editor._all.style.position="absolute";
	editor._all.style.height="100%";
	editor._all.style.width="100%";
	editor._all.style.top=0;
	editor._all.style.left=0;
	editor._textArea.style.height=window.innerHeight-editor._toolbar.offsetHeight/3-5-33;
	editor._iframe.style.height=window.innerHeight-editor._toolbar.offsetHeight-5-53;
	try{
		iframep.style.height=editor._textArea.style.height;
	}catch(e){
	}
	
}else{
	
	window.resizeTo(mvOWidth, mvOHeight);
	window.moveTo(mvScrX, mvScrY);
	editor._all.style.position="static";
	editor._all.style.height=hah;
	editor._all.style.width=haw;
	editor._all.style.top=hat;
	editor._all.style.left=hal;
	editor._textArea.style.height=x3;
	editor._iframe.style.height=x1;
	try{
		iframep.style.height=x2;
	}catch(e){
	
	}
	
}
try{
	this._doc.designMode = "on";
}catch(e){
}
};

// EOF
// Local variables: //
// c-basic-offset:8 //
// indent-tabs-mode:t //
// End: //